# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .subscription import SubscriptionParams


class CreateSubscriptionResponseParams(typing_extensions.TypedDict):
    """
    Defines output parameters in a response from the
    [CreateSubscription](api-endpoint:Subscriptions-CreateSubscription) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered during the request.
    """

    subscription: typing_extensions.NotRequired[SubscriptionParams]
    """
    The newly created subscription.
    
    For more information, see
    [Subscription object](https://developer.squareup.com/docs/subscriptions-api/manage-subscriptions#subscription-object).
    """
