# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .customer import CustomerParams


class ListCustomersResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the `ListCustomers` endpoint.

    Either `errors` or `customers` is present in a given response (never both).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    customers: typing_extensions.NotRequired[typing.Sequence[CustomerParams]]
    """
    The customer profiles associated with the Square account or an empty object (`{}`) if none are found.
    Only customer profiles with public information (`given_name`, `family_name`, `company_name`, `email_address`, or
    `phone_number`) are included in the response.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    A pagination cursor to retrieve the next set of results for the
    original query. A cursor is only present if the request succeeded and additional results
    are available.
    
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """

    count: typing_extensions.NotRequired[int]
    """
    The total count of customers associated with the Square account. Only customer profiles with public information
    (`given_name`, `family_name`, `company_name`, `email_address`, or `phone_number`) are counted. This field is present
    only if `count` is set to `true` in the request.
    """
