# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment import PaymentParams


class CancelPaymentResponseParams(typing_extensions.TypedDict):
    """
    Defines the response returned by [CancelPayment](api-endpoint:Payments-CancelPayment).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    payment: typing_extensions.NotRequired[PaymentParams]
    """
    The successfully canceled `Payment` object.
    """
