# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .search_team_members_filter import SearchTeamMembersFilterParams


class SearchTeamMembersQueryParams(typing_extensions.TypedDict):
    """
    Represents the parameters in a search for `TeamMember` objects.
    """

    filter: typing_extensions.NotRequired[SearchTeamMembersFilterParams]
    """
    The options to filter by.
    """
