# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .delete_order_custom_attribute_response import DeleteOrderCustomAttributeResponseParams


class BulkDeleteOrderCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from deleting one or more order custom attributes.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    values: typing.Dict[str, DeleteOrderCustomAttributeResponseParams]
    """
     A map of responses that correspond to individual delete requests. Each response has the same ID 
    as the corresponding request and contains either a `custom_attribute` or an `errors` field.
    """
