# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.catalog_item_food_and_beverage_details_dietary_preference_type import (
    CatalogItemFoodAndBeverageDetailsDietaryPreferenceType,
)
from ..types.catalog_item_food_and_beverage_details_ingredient_standard_ingredient import (
    CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient,
)
import typing


class CatalogItemFoodAndBeverageDetailsIngredientParams(typing_extensions.TypedDict):
    """
    Describes the ingredient used in a `FOOD_AND_BEV` item.
    """

    type: typing_extensions.NotRequired[CatalogItemFoodAndBeverageDetailsDietaryPreferenceType]
    """
    The dietary preference type of the ingredient. Supported values include `STANDARD` and `CUSTOM` as specified in `FoodAndBeverageDetails.DietaryPreferenceType`.
    See [DietaryPreferenceType](#type-dietarypreferencetype) for possible values
    """

    standard_name: typing_extensions.NotRequired[CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient]
    """
    The name of the ingredient from a standard pre-defined list. This should be null if it's a custom dietary preference.
    See [StandardIngredient](#type-standardingredient) for possible values
    """

    custom_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of a custom user-defined ingredient. This should be null if it's a standard dietary preference.
    """
