# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .availability import AvailabilityParams
from .error import ErrorParams


class SearchAvailabilityResponseParams(typing_extensions.TypedDict):
    availabilities: typing_extensions.NotRequired[typing.Sequence[AvailabilityParams]]
    """
    List of appointment slots available for booking.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
