# This file was auto-generated by Fern from our API Definition.

import typing

BookingBookingSource = typing.Union[
    typing.Literal["FIRST_PARTY_MERCHANT", "FIRST_PARTY_BUYER", "THIRD_PARTY_BUYER", "API"], typing.Any
]
