# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CheckoutLocationSettingsPolicy(UncheckedBaseModel):
    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    A unique ID to identify the policy when making changes. You must set the UID for policy updates, but it’s optional when setting new policies.
    """

    title: typing.Optional[str] = pydantic.Field(default=None)
    """
    The title of the policy. This is required when setting the description, though you can update it in a different request.
    """

    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the policy.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
