# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class ShippingFeeParams(typing_extensions.TypedDict):
    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name for the shipping fee.
    """

    charge: MoneyParams
    """
    The amount and currency for the shipping fee.
    """
