# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class DeviceComponentDetailsMeasurementParams(typing_extensions.TypedDict):
    """
    A value qualified by unit of measure.
    """

    value: typing_extensions.NotRequired[typing.Optional[int]]
