# This file was auto-generated by Fern from our API Definition.

import typing

ComponentComponentType = typing.Union[
    typing.Literal["APPLICATION", "CARD_READER", "BATTERY", "WIFI", "ETHERNET", "PRINTER"], typing.Any
]
