# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .money import MoneyParams
import typing
from ..types.payout_fee_type import PayoutFeeType


class PayoutFeeParams(typing_extensions.TypedDict):
    """
    Represents a payout fee that can incur as part of a payout.
    """

    amount_money: typing_extensions.NotRequired[MoneyParams]
    """
    The money amount of the payout fee.
    """

    effective_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The timestamp of when the fee takes effect, in RFC 3339 format.
    """

    type: typing_extensions.NotRequired[PayoutFeeType]
    """
    The type of fee assessed as part of the payout.
    See [PayoutFeeType](#type-payoutfeetype) for possible values
    """
