# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .customer_text_filter import CustomerTextFilterParams
from ..types.country import Country


class CustomerAddressFilterParams(typing_extensions.TypedDict):
    """
    The customer address filter. This filter is used in a [CustomerCustomAttributeFilterValue](entity:CustomerCustomAttributeFilterValue) filter when
    searching by an `Address`-type custom attribute.
    """

    postal_code: typing_extensions.NotRequired[CustomerTextFilterParams]
    """
    The postal code to search for. Only an `exact` match is supported.
    """

    country: typing_extensions.NotRequired[Country]
    """
    The country code to search for.
    See [Country](#type-country) for possible values
    """
