# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams


class ChargeRequestAdditionalRecipientParams(typing_extensions.TypedDict):
    """
    Represents an additional recipient (other than the merchant) entitled to a portion of the tender.
    Support is currently limited to USD, CAD and GBP currencies
    """

    location_id: str
    """
    The location ID for a recipient (other than the merchant) receiving a portion of the tender.
    """

    description: str
    """
    The description of the additional recipient.
    """

    amount_money: MoneyParams
    """
    The amount of money distributed to the recipient.
    """
