# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .v1order_history_entry_action import V1OrderHistoryEntryAction
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class V1OrderHistoryEntry(UncheckedBaseModel):
    """
    V1OrderHistoryEntry
    """

    action: typing.Optional[V1OrderHistoryEntryAction] = pydantic.Field(default=None)
    """
    The type of action performed on the order.
    See [V1OrderHistoryEntryAction](#type-v1orderhistoryentryaction) for possible values
    """

    created_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The time when the action was performed, in ISO 8601 format.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
