# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .cash_drawer_shift import CashDrawerShiftParams
import typing
from .error import ErrorParams


class GetCashDrawerShiftResponseParams(typing_extensions.TypedDict):
    cash_drawer_shift: typing_extensions.NotRequired[CashDrawerShiftParams]
    """
    The cash drawer shift queried for.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
