# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class OrderPricingOptionsParams(typing_extensions.TypedDict):
    """
    Pricing options for an order. The options affect how the order's price is calculated.
    They can be used, for example, to apply automatic price adjustments that are based on preconfigured
    [pricing rules](entity:CatalogPricingRule).
    """

    auto_apply_discounts: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    The option to determine whether pricing rule-based
    discounts are automatically applied to an order.
    """

    auto_apply_taxes: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    The option to determine whether rule-based taxes are automatically
    applied to an order when the criteria of the corresponding rules are met.
    """
