# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .device_component_details_measurement import DeviceComponentDetailsMeasurementParams


class DeviceComponentDetailsWiFiDetailsParams(typing_extensions.TypedDict):
    active: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    A boolean to represent whether the WiFI interface is currently active.
    """

    ssid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the connected WIFI network.
    """

    ip_address_v4: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The string representation of the device’s IPv4 address.
    """

    secure_connection: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The security protocol for a secure connection (e.g. WPA2). None provided if the connection
    is unsecured.
    """

    signal_strength: typing_extensions.NotRequired[DeviceComponentDetailsMeasurementParams]
    """
    A representation of signal strength of the WIFI network connection.
    """
