# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.day_of_week import DayOfWeek
import typing


class BusinessHoursPeriodParams(typing_extensions.TypedDict):
    """
    Represents a period of time during which a business location is open.
    """

    day_of_week: typing_extensions.NotRequired[DayOfWeek]
    """
    The day of the week for this time period.
    See [DayOfWeek](#type-dayofweek) for possible values
    """

    start_local_time: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The start time of a business hours period, specified in local time using partial-time
    RFC 3339 format. For example, `8:30:00` for a period starting at 8:30 in the morning.
    Note that the seconds value is always :00, but it is appended for conformance to the RFC.
    """

    end_local_time: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The end time of a business hours period, specified in local time using partial-time
    RFC 3339 format. For example, `21:00:00` for a period ending at 9:00 in the evening.
    Note that the seconds value is always :00, but it is appended for conformance to the RFC.
    """
