# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.catalog_item_food_and_beverage_details_dietary_preference_type import (
    CatalogItemFoodAndBeverageDetailsDietaryPreferenceType,
)
from ..types.catalog_item_food_and_beverage_details_dietary_preference_standard_dietary_preference import (
    CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference,
)
import typing


class CatalogItemFoodAndBeverageDetailsDietaryPreferenceParams(typing_extensions.TypedDict):
    """
    Dietary preferences that can be assigned to an `FOOD_AND_BEV` item and its ingredients.
    """

    type: typing_extensions.NotRequired[CatalogItemFoodAndBeverageDetailsDietaryPreferenceType]
    """
    The dietary preference type. Supported values include `STANDARD` and `CUSTOM` as specified in `FoodAndBeverageDetails.DietaryPreferenceType`.
    See [DietaryPreferenceType](#type-dietarypreferencetype) for possible values
    """

    standard_name: typing_extensions.NotRequired[
        CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference
    ]
    """
    The name of the dietary preference from a standard pre-defined list. This should be null if it's a custom dietary preference.
    See [StandardDietaryPreference](#type-standarddietarypreference) for possible values
    """

    custom_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of a user-defined custom dietary preference. This should be null if it's a standard dietary preference.
    """
