# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class OrderReturnTipParams(typing_extensions.TypedDict):
    """
    A tip being returned.
    """

    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID that identifies the tip only within this order.
    """

    applied_money: typing_extensions.NotRequired[MoneyParams]
    """
    The amount of tip being returned
    --
    """

    source_tender_uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The tender `uid` from the order that contains the original application of this tip.
    """

    source_tender_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The tender `id` from the order that contains the original application of this tip.
    """
