# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionActionType = typing.Union[
    typing.Literal["CANCEL", "PAUSE", "RESUME", "SWAP_PLAN", "CHANGE_BILLING_ANCHOR_DATE"], typing.Any
]
