# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class LoyaltyEventAccumulatePointsParams(typing_extensions.TypedDict):
    """
    Provides metadata when the event `type` is `ACCUMULATE_POINTS`.
    """

    loyalty_program_id: typing_extensions.NotRequired[str]
    """
    The ID of the [loyalty program](entity:LoyaltyProgram).
    """

    points: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The number of points accumulated by the event.
    """

    order_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the [order](entity:Order) for which the buyer accumulated the points.
    This field is returned only if the Orders API is used to process orders.
    """
