# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementUnitUnitType = typing.Union[
    typing.Literal["TYPE_CUSTOM", "TYPE_AREA", "TYPE_LENGTH", "TYPE_VOLUME", "TYPE_WEIGHT", "TYPE_GENERIC"], typing.Any
]
