# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from ..types.register_domain_response_status import RegisterDomainResponseStatus


class RegisterDomainResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the [RegisterDomain](api-endpoint:ApplePay-RegisterDomain) endpoint.

    Either `errors` or `status` are present in a given response (never both).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    status: typing_extensions.NotRequired[RegisterDomainResponseStatus]
    """
    The status of the domain registration.
    
    See [RegisterDomainResponseStatus](entity:RegisterDomainResponseStatus) for possible values.
    See [RegisterDomainResponseStatus](#type-registerdomainresponsestatus) for possible values
    """
