# This file was auto-generated by Fern from our API Definition.

import typing

FulfillmentDeliveryDetailsOrderFulfillmentDeliveryDetailsScheduleType = typing.Union[
    typing.Literal["SCHEDULED", "ASAP"], typing.Any
]
