# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .custom_attribute import CustomAttributeParams
import typing
from .error import ErrorParams


class RetrieveOrderCustomAttributeResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from getting an order custom attribute.
    """

    custom_attribute: typing_extensions.NotRequired[CustomAttributeParams]
    """
    The retrieved custom attribute. If `with_definition` was set to `true` in the request, the custom attribute definition is returned in the `definition field.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
