# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogQueryRangeParams(typing_extensions.TypedDict):
    """
    The query filter to return the search result whose named attribute values fall between the specified range.
    """

    attribute_name: str
    """
    The name of the attribute to be searched.
    """

    attribute_min_value: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The desired minimum value for the search attribute (inclusive).
    """

    attribute_max_value: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The desired maximum value for the search attribute (inclusive).
    """
