# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class QrCodeOptionsParams(typing_extensions.TypedDict):
    """
    Fields to describe the action that displays QR-Codes.
    """

    title: str
    """
    The title text to display in the QR code flow on the Terminal.
    """

    body: str
    """
    The body text to display in the QR code flow on the Terminal.
    """

    barcode_contents: str
    """
    The text representation of the data to show in the QR code
    as UTF8-encoded data.
    """
