# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .checkout_merchant_settings_payment_methods_payment_method import (
    CheckoutMerchantSettingsPaymentMethodsPaymentMethodParams,
)
from .checkout_merchant_settings_payment_methods_afterpay_clearpay import (
    CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayParams,
)


class CheckoutMerchantSettingsPaymentMethodsParams(typing_extensions.TypedDict):
    apple_pay: typing_extensions.NotRequired[CheckoutMerchantSettingsPaymentMethodsPaymentMethodParams]
    google_pay: typing_extensions.NotRequired[CheckoutMerchantSettingsPaymentMethodsPaymentMethodParams]
    cash_app: typing_extensions.NotRequired[CheckoutMerchantSettingsPaymentMethodsPaymentMethodParams]
    afterpay_clearpay: typing_extensions.NotRequired[CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayParams]
