# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class BookingCustomAttributeDeleteRequestParams(typing_extensions.TypedDict):
    """
    Represents an individual delete request in a [BulkDeleteBookingCustomAttributes](api-endpoint:BookingCustomAttributes-BulkDeleteBookingCustomAttributes)
    request. An individual request contains a booking ID, the custom attribute to delete, and an optional idempotency key.
    """

    booking_id: str
    """
    The ID of the target [booking](entity:Booking).
    """

    key: str
    """
    The key of the custom attribute to delete. This key must match the `key` of a
    custom attribute definition in the Square seller account. If the requesting application is not
    the definition owner, you must use the qualified key.
    """
