# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .money import Money
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class ChargeRequestAdditionalRecipient(UncheckedBaseModel):
    """
    Represents an additional recipient (other than the merchant) entitled to a portion of the tender.
    Support is currently limited to USD, CAD and GBP currencies
    """

    location_id: str = pydantic.Field()
    """
    The location ID for a recipient (other than the merchant) receiving a portion of the tender.
    """

    description: str = pydantic.Field()
    """
    The description of the additional recipient.
    """

    amount_money: Money = pydantic.Field()
    """
    The amount of money distributed to the recipient.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
