# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment_link import PaymentLinkParams
from .payment_link_related_resources import PaymentLinkRelatedResourcesParams


class CreatePaymentLinkResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    payment_link: typing_extensions.NotRequired[PaymentLinkParams]
    """
    The created payment link.
    """

    related_resources: typing_extensions.NotRequired[PaymentLinkRelatedResourcesParams]
    """
    The list of related objects.
    """
