# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.risk_evaluation_risk_level import RiskEvaluationRiskLevel


class RiskEvaluationParams(typing_extensions.TypedDict):
    """
    Represents fraud risk information for the associated payment.

    When you take a payment through Square's Payments API (using the `CreatePayment`
    endpoint), Square evaluates it and assigns a risk level to the payment. Sellers
    can use this information to determine the course of action (for example,
    provide the goods/services or refund the payment).
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp when payment risk was evaluated, in RFC 3339 format.
    """

    risk_level: typing_extensions.NotRequired[RiskEvaluationRiskLevel]
    """
    The risk level associated with the payment
    See [RiskEvaluationRiskLevel](#type-riskevaluationrisklevel) for possible values
    """
