# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .invoice_filter import InvoiceFilterParams
import typing_extensions
from .invoice_sort import InvoiceSortParams


class InvoiceQueryParams(typing_extensions.TypedDict):
    """
    Describes query criteria for searching invoices.
    """

    filter: InvoiceFilterParams
    """
    Query filters to apply in searching invoices. 
    For more information, see [Search for invoices](https://developer.squareup.com/docs/invoices-api/retrieve-list-search-invoices#search-invoices).
    """

    sort: typing_extensions.NotRequired[InvoiceSortParams]
    """
    Describes the sort order for the search result.
    """
