# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams
import typing_extensions


class CashPaymentDetailsParams(typing_extensions.TypedDict):
    """
    Stores details about a cash payment. Contains only non-confidential information. For more information, see
    [Take Cash Payments](https://developer.squareup.com/docs/payments-api/take-payments/cash-payments).
    """

    buyer_supplied_money: MoneyParams
    """
    The amount and currency of the money supplied by the buyer.
    """

    change_back_money: typing_extensions.NotRequired[MoneyParams]
    """
    The amount of change due back to the buyer. 
    This read-only field is calculated
    from the `amount_money` and `buyer_supplied_money` fields.
    """
