# This file was auto-generated by Fern from our API Definition.

import typing

TeamMemberAssignedLocationsAssignmentType = typing.Union[
    typing.Literal["ALL_CURRENT_AND_FUTURE_LOCATIONS", "EXPLICIT_LOCATIONS"], typing.Any
]
