# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CustomerDetails(UncheckedBaseModel):
    """
    Details about the customer making the payment.
    """

    customer_initiated: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates whether the customer initiated the payment.
    """

    seller_keyed_in: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates that the seller keyed in payment details on behalf of the customer.
    This is used to flag a payment as Mail Order / Telephone Order (MOTO).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
