# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.invoice_sort_field import InvoiceSortField
import typing_extensions
from ..types.sort_order import SortOrder


class InvoiceSortParams(typing_extensions.TypedDict):
    """
    Identifies the sort field and sort order.
    """

    field: InvoiceSortField
    """
    The field to use for sorting.
    See [InvoiceSortField](#type-invoicesortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    The order to use for sorting the results.
    See [SortOrder](#type-sortorder) for possible values
    """
