# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .team_member_assigned_locations_assignment_type import TeamMemberAssignedLocationsAssignmentType
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TeamMemberAssignedLocations(UncheckedBaseModel):
    """
    An object that represents a team member's assignment to locations.
    """

    assignment_type: typing.Optional[TeamMemberAssignedLocationsAssignmentType] = pydantic.Field(default=None)
    """
    The current assignment type of the team member.
    See [TeamMemberAssignedLocationsAssignmentType](#type-teammemberassignedlocationsassignmenttype) for possible values
    """

    location_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The explicit locations that the team member is assigned to.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
