# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .money import Money
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GiftCardActivityImportReversal(UncheckedBaseModel):
    """
    Represents details about an `IMPORT_REVERSAL` [gift card activity type](entity:GiftCardActivityType).
    """

    amount_money: Money = pydantic.Field()
    """
    The amount of money cleared from the third-party gift card when 
    the import was reversed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
