# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .custom_attribute import CustomAttributeParams
import typing
from .error import ErrorParams


class BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponseParams(
    typing_extensions.TypedDict
):
    """
    Represents a response for an individual upsert request in a [BulkUpsertMerchantCustomAttributes](api-endpoint:MerchantCustomAttributes-BulkUpsertMerchantCustomAttributes) operation.
    """

    merchant_id: typing_extensions.NotRequired[str]
    """
    The ID of the merchant associated with the custom attribute.
    """

    custom_attribute: typing_extensions.NotRequired[CustomAttributeParams]
    """
    The new or updated custom attribute.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred while processing the individual request.
    """
