# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class OrderSource(UncheckedBaseModel):
    """
    Represents the origination details of an order.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name used to identify the place (physical or digital) that an order originates.
    If unset, the name defaults to the name of the application that created the order.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
