# This file was auto-generated by Fern from our API Definition.

import typing

CatalogDiscountType = typing.Union[
    typing.Literal["FIXED_PERCENTAGE", "FIXED_AMOUNT", "VARIABLE_PERCENTAGE", "VARIABLE_AMOUNT"], typing.Any
]
