# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogEcomSeoDataParams(typing_extensions.TypedDict):
    """
    SEO data for for a seller's Square Online store.
    """

    page_title: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The SEO title used for the Square Online store.
    """

    page_description: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The SEO description used for the Square Online store.
    """

    permalink: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The SEO permalink used for the Square Online store.
    """
