# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .catalog_object import CatalogObjectParams


class GetCatalogObjectResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    object: typing_extensions.NotRequired[CatalogObjectParams]
    """
    The `CatalogObject`s returned.
    """

    related_objects: typing_extensions.NotRequired[typing.Sequence[CatalogObjectParams]]
    """
    A list of `CatalogObject`s referenced by the object in the `object` field.
    """
