# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .cash_drawer_shift_event import CashDrawerShiftEventParams


class ListCashDrawerShiftEventsResponseParams(typing_extensions.TypedDict):
    cursor: typing_extensions.NotRequired[str]
    """
    Opaque cursor for fetching the next page. Cursor is not present in
    the last page of results.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    cash_drawer_shift_events: typing_extensions.NotRequired[typing.Sequence[CashDrawerShiftEventParams]]
    """
    All of the events (payments, refunds, etc.) for a cash drawer during
    the shift.
    """
