# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.employee_status import EmployeeStatus


class EmployeeParams(typing_extensions.TypedDict):
    """
    An employee object that is used by the external API.

    DEPRECATED at version 2020-08-26. Replaced by [TeamMember](entity:TeamMember).
    """

    id: typing_extensions.NotRequired[str]
    """
    UUID for this object.
    """

    first_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The employee's first name.
    """

    last_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The employee's last name.
    """

    email: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The employee's email address
    """

    phone_number: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The employee's phone number in E.164 format, i.e. "+12125554250"
    """

    location_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A list of location IDs where this employee has access to.
    """

    status: typing_extensions.NotRequired[EmployeeStatus]
    """
    Specifies the status of the employees being fetched.
    See [EmployeeStatus](#type-employeestatus) for possible values
    """

    is_owner: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether this employee is the owner of the merchant. Each merchant
    has one owner employee, and that employee has full authority over
    the account.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    A read-only timestamp in RFC 3339 format.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    A read-only timestamp in RFC 3339 format.
    """
