# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_event import LoyaltyEventParams


class AdjustLoyaltyPointsResponseParams(typing_extensions.TypedDict):
    """
    Represents an [AdjustLoyaltyPoints](api-endpoint:Loyalty-AdjustLoyaltyPoints) request.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    event: typing_extensions.NotRequired[LoyaltyEventParams]
    """
    The resulting event data for the adjustment.
    """
