# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class OrderSourceParams(typing_extensions.TypedDict):
    """
    Represents the origination details of an order.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name used to identify the place (physical or digital) that an order originates.
    If unset, the name defaults to the name of the application that created the order.
    """
