# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.checkout_location_settings_branding_header_type import CheckoutLocationSettingsBrandingHeaderType
import typing
from ..types.checkout_location_settings_branding_button_shape import CheckoutLocationSettingsBrandingButtonShape


class CheckoutLocationSettingsBrandingParams(typing_extensions.TypedDict):
    header_type: typing_extensions.NotRequired[CheckoutLocationSettingsBrandingHeaderType]
    """
    Show the location logo on the checkout page.
    See [HeaderType](#type-headertype) for possible values
    """

    button_color: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The HTML-supported hex color for the button on the checkout page (for example, "#FFFFFF").
    """

    button_shape: typing_extensions.NotRequired[CheckoutLocationSettingsBrandingButtonShape]
    """
    The shape of the button on the checkout page.
    See [ButtonShape](#type-buttonshape) for possible values
    """
