# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CatalogItemOptionForItem(UncheckedBaseModel):
    """
     An option that can be assigned to an item.
    For example, a t-shirt item may offer a color option or a size option.
    """

    item_option_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The unique id of the item option, used to form the dimensions of the item option matrix in a specified order.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
