# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .publish_scheduled_shift_response import PublishScheduledShiftResponseParams
from .error import ErrorParams


class BulkPublishScheduledShiftsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [BulkPublishScheduledShifts](api-endpoint:Labor-BulkPublishScheduledShifts) response.
    Either `scheduled_shifts` or `errors` is present in the response.
    """

    responses: typing_extensions.NotRequired[typing.Dict[str, PublishScheduledShiftResponseParams]]
    """
    A map of key-value pairs that represent responses for individual publish requests.
    The order of responses might differ from the order in which the requests were provided.
    
    - Each key is the scheduled shift ID that was specified for a publish request.
    - Each value is the corresponding response. If the request succeeds, the value is the
    published scheduled shift. If the request fails, the value is an `errors` array containing
    any errors that occurred while processing the request.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any top-level errors that prevented the bulk operation from succeeding.
    """
