# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .get_vendor_response import GetVendorResponseParams


class BatchGetVendorsResponseParams(typing_extensions.TypedDict):
    """
    Represents an output from a call to [BulkRetrieveVendors](api-endpoint:Vendors-BulkRetrieveVendors).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    responses: typing_extensions.NotRequired[typing.Dict[str, GetVendorResponseParams]]
    """
    The set of [RetrieveVendorResponse](entity:RetrieveVendorResponse) objects encapsulating successfully retrieved [Vendor](entity:Vendor)
    objects or error responses for failed attempts. The set is represented by 
    a collection of `Vendor`-ID/`Vendor`-object or `Vendor`-ID/error-object pairs.
    """
