# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .custom_attribute import CustomAttributeParams
from .error import ErrorParams


class ListOrderCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from listing order custom attributes.
    """

    custom_attributes: typing_extensions.NotRequired[typing.Sequence[CustomAttributeParams]]
    """
    The retrieved custom attributes. If no custom attribute are found, Square returns an empty object (`{}`).
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The cursor to provide in your next call to this endpoint to retrieve the next page of results for your original request. 
    This field is present only if the request succeeded and additional results are available.
    For more information, see [Pagination](https://developer.squareup.com/docs/working-with-apis/pagination).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
