# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .order import OrderParams
from .error import ErrorParams


class BatchGetOrdersResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the `BatchRetrieveOrders` endpoint.
    """

    orders: typing_extensions.NotRequired[typing.Sequence[OrderParams]]
    """
    The requested orders. This will omit any requested orders that do not exist.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
