# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .signature_image import SignatureImageParams


class SignatureOptionsParams(typing_extensions.TypedDict):
    title: str
    """
    The title text to display in the signature capture flow on the Terminal.
    """

    body: str
    """
    The body text to display in the signature capture flow on the Terminal.
    """

    signature: typing_extensions.NotRequired[typing.Sequence[SignatureImageParams]]
    """
    An image representation of the collected signature.
    """
