# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_event import LoyaltyEventParams


class SearchLoyaltyEventsResponseParams(typing_extensions.TypedDict):
    """
    A response that contains loyalty events that satisfy the search
    criteria, in order by the `created_at` date.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    events: typing_extensions.NotRequired[typing.Sequence[LoyaltyEventParams]]
    """
    The loyalty events that satisfy the search criteria.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in a subsequent 
    request. If empty, this is the final response. 
    For more information, 
    see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
