# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class SnippetParams(typing_extensions.TypedDict):
    """
    Represents the snippet that is added to a Square Online site. The snippet code is injected into the `head` element of all pages on the site, except for checkout pages.
    """

    id: typing_extensions.NotRequired[str]
    """
    The Square-assigned ID for the snippet.
    """

    site_id: typing_extensions.NotRequired[str]
    """
    The ID of the site that contains the snippet.
    """

    content: str
    """
    The snippet code, which can contain valid HTML, JavaScript, or both.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the snippet was initially added to the site, in RFC 3339 format.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the snippet was last updated on the site, in RFC 3339 format.
    """
