# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LoyaltyEventLoyaltyAccountFilterParams(typing_extensions.TypedDict):
    """
    Filter events by loyalty account.
    """

    loyalty_account_id: str
    """
    The ID of the [loyalty account](entity:LoyaltyAccount) associated with loyalty events.
    """
