# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.gift_card_activity_deactivate_reason import GiftCardActivityDeactivateReason


class GiftCardActivityDeactivateParams(typing_extensions.TypedDict):
    """
    Represents details about a `DEACTIVATE` [gift card activity type](entity:GiftCardActivityType).
    """

    reason: GiftCardActivityDeactivateReason
    """
    The reason the gift card was deactivated.
    See [Reason](#type-reason) for possible values
    """
