# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class TimecardWageParams(typing_extensions.TypedDict):
    """
    The hourly wage rate used to compensate a team member for a [timecard](entity:Timecard).
    """

    title: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the job performed during this timecard.
    """

    hourly_rate: typing_extensions.NotRequired[MoneyParams]
    """
    Can be a custom-set hourly wage or the calculated effective hourly
    wage based on the annual wage and hours worked per week.
    """

    job_id: typing_extensions.NotRequired[str]
    """
    The ID of the [job](entity:Job) performed for this timecard. Square
    labor-reporting UIs might group timecards together by ID.
    """

    tip_eligible: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether team members are eligible for tips when working this job.
    """
