# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .card import CardParams
import typing


class DestinationDetailsCardRefundDetailsParams(typing_extensions.TypedDict):
    card: typing_extensions.NotRequired[CardParams]
    """
    The card's non-confidential details.
    """

    entry_method: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The method used to enter the card's details for the refund. The method can be
    `KEYED`, `SWIPED`, `EMV`, `ON_FILE`, or `CONTACTLESS`.
    """

    auth_result_code: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The authorization code provided by the issuer when a refund is approved.
    """
