# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .location_booking_profile import LocationBookingProfileParams
import typing
from .error import ErrorParams


class RetrieveLocationBookingProfileResponseParams(typing_extensions.TypedDict):
    location_booking_profile: typing_extensions.NotRequired[LocationBookingProfileParams]
    """
    The requested location booking profile.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
