# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.currency import Currency


class V1MoneyParams(typing_extensions.TypedDict):
    amount: typing_extensions.NotRequired[typing.Optional[int]]
    """
    Amount in the lowest denominated value of this Currency. E.g. in USD
    these are cents, in JPY they are Yen (which do not have a 'cent' concept).
    """

    currency_code: typing_extensions.NotRequired[Currency]
    """
    
    See [Currency](#type-currency) for possible values
    """
