# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.search_events_sort_field import SearchEventsSortField
from ..types.sort_order import SortOrder


class SearchEventsSortParams(typing_extensions.TypedDict):
    """
    Criteria to sort events by.
    """

    field: typing_extensions.NotRequired[SearchEventsSortField]
    """
    Sort events by event types.
    See [SearchEventsSortField](#type-searcheventssortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    The order to use for sorting the events.
    See [SortOrder](#type-sortorder) for possible values
    """
