# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class AdditionalRecipientParams(typing_extensions.TypedDict):
    """
    Represents an additional recipient (other than the merchant) receiving a portion of this tender.
    """

    location_id: str
    """
    The location ID for a recipient (other than the merchant) receiving a portion of this tender.
    """

    description: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The description of the additional recipient.
    """

    amount_money: MoneyParams
    """
    The amount of money distributed to the recipient.
    """

    receivable_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The unique ID for the RETIRED `AdditionalRecipientReceivable` object. This field should be empty for any `AdditionalRecipient` objects created after the retirement.
    """
