# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing


class CatalogQueryItemsForTaxParams(typing_extensions.TypedDict):
    """
    The query filter to return the items containing the specified tax IDs.
    """

    tax_ids: typing.Sequence[str]
    """
    A set of `CatalogTax` IDs to be used to find associated `CatalogItem`s.
    """
