# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CashDrawerDeviceParams(typing_extensions.TypedDict):
    id: typing_extensions.NotRequired[str]
    """
    The device Square-issued ID
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The device merchant-specified name.
    """
