# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogItemOptionValueForItemVariationParams(typing_extensions.TypedDict):
    """
    A `CatalogItemOptionValue` links an item variation to an item option as
    an item option value. For example, a t-shirt item may offer a color option and
    a size option. An item option value would represent each variation of t-shirt:
    For example, "Color:Red, Size:Small" or "Color:Blue, Size:Medium".
    """

    item_option_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The unique id of an item option.
    """

    item_option_value_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The unique id of the selected value for the item option.
    """
