# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .location import LocationParams


class UpdateLocationResponseParams(typing_extensions.TypedDict):
    """
    The response object returned by the [UpdateLocation](api-endpoint:Locations-UpdateLocation) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    location: typing_extensions.NotRequired[LocationParams]
    """
    The updated `Location` object.
    """
