# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .inventory_physical_count import InventoryPhysicalCountParams


class GetInventoryPhysicalCountResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    count: typing_extensions.NotRequired[InventoryPhysicalCountParams]
    """
    The requested [InventoryPhysicalCount](entity:InventoryPhysicalCount).
    """
