# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .team_member import TeamMemberParams
import typing
from .error import ErrorParams


class CreateTeamMemberResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from a create request containing the created `TeamMember` object or error messages.
    """

    team_member: typing_extensions.NotRequired[TeamMemberParams]
    """
    The successfully created `TeamMember` object.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    The errors that occurred during the request.
    """
