# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogModifierOverrideParams(typing_extensions.TypedDict):
    """
    Options to control how to override the default behavior of the specified modifier.
    """

    modifier_id: str
    """
    The ID of the `CatalogModifier` whose default behavior is being overridden.
    """

    on_by_default: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    __Deprecated__: Use `on_by_default_override` instead.
    """

    hidden_online_override: typing_extensions.NotRequired[typing.Optional[typing.Any]]
    on_by_default_override: typing_extensions.NotRequired[typing.Optional[typing.Any]]
