# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams


class GiftCardActivityTransferBalanceFromParams(typing_extensions.TypedDict):
    """
    Represents details about a `TRANSFER_BALANCE_FROM` [gift card activity type](entity:GiftCardActivityType).
    """

    transfer_to_gift_card_id: str
    """
    The ID of the gift card to which the specified amount was transferred.
    """

    amount_money: MoneyParams
    """
    The amount deducted from the gift card for the transfer. This value is a positive integer.
    """
