# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .time_range import TimeRangeParams


class SearchEventsFilterParams(typing_extensions.TypedDict):
    """
    Criteria to filter events by.
    """

    event_types: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    Filter events by event types.
    """

    merchant_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    Filter events by merchant.
    """

    location_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    Filter events by location.
    """

    created_at: typing_extensions.NotRequired[TimeRangeParams]
    """
    Filter events by when they were created.
    """
