# This file was auto-generated by Fern from our API Definition.

import typing

CheckoutLocationSettingsBrandingHeaderType = typing.Union[
    typing.Literal["BUSINESS_NAME", "FRAMED_LOGO", "FULL_WIDTH_LOGO"], typing.Any
]
