# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .dispute import DisputeParams


class SubmitEvidenceResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields in a `SubmitEvidence` response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    dispute: typing_extensions.NotRequired[DisputeParams]
    """
    The `Dispute` for which evidence was submitted.
    """
