# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class CreateInvoiceAttachmentRequestDataParams(typing_extensions.TypedDict):
    """
    Represents a [CreateInvoiceAttachment](api-endpoint:Invoices-CreateInvoiceAttachment) request.
    """

    idempotency_key: typing_extensions.NotRequired[str]
    """
    A unique string that identifies the `CreateInvoiceAttachment` request.
    For more information, see [Idempotency](https://developer.squareup.com/docs/build-basics/common-api-patterns/idempotency).
    """

    description: typing_extensions.NotRequired[str]
    """
    The description of the attachment to display on the invoice.
    """
