# This file was auto-generated by Fern from our API Definition.

import typing

DisputeState = typing.Union[
    typing.Literal[
        "INQUIRY_EVIDENCE_REQUIRED",
        "INQUIRY_PROCESSING",
        "INQUIRY_CLOSED",
        "EVIDENCE_REQUIRED",
        "PROCESSING",
        "WON",
        "LOST",
        "ACCEPTED",
    ],
    typing.Any,
]
