# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .subscription_test_result import SubscriptionTestResultParams


class TestWebhookSubscriptionResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the [TestWebhookSubscription](api-endpoint:WebhookSubscriptions-TestWebhookSubscription) endpoint.

    Note: If there are errors processing the request, the [SubscriptionTestResult](entity:SubscriptionTestResult) field is not
    present.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information on errors encountered during the request.
    """

    subscription_test_result: typing_extensions.NotRequired[SubscriptionTestResultParams]
    """
    The [SubscriptionTestResult](entity:SubscriptionTestResult).
    """
