# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .confirmation_decision import ConfirmationDecision
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ConfirmationOptions(UncheckedBaseModel):
    title: str = pydantic.Field()
    """
    The title text to display in the confirmation screen flow on the Terminal.
    """

    body: str = pydantic.Field()
    """
    The agreement details to display in the confirmation flow on the Terminal.
    """

    agree_button_text: str = pydantic.Field()
    """
    The button text to display indicating the customer agrees to the displayed terms.
    """

    disagree_button_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    The button text to display indicating the customer does not agree to the displayed terms.
    """

    decision: typing.Optional[ConfirmationDecision] = pydantic.Field(default=None)
    """
    The result of the buyer’s actions when presented with the confirmation screen.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
