# This file was auto-generated by Fern from our API Definition.

import typing

LoyaltyProgramAccrualRuleType = typing.Union[typing.Literal["VISIT", "SPEND", "ITEM_VARIATION", "CATEGORY"], typing.Any]
