# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class ModifierLocationOverridesParams(typing_extensions.TypedDict):
    """
    Location-specific overrides for specified properties of a `CatalogModifier` object.
    """

    location_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the `Location` object representing the location. This can include a deactivated location.
    """

    price_money: typing_extensions.NotRequired[MoneyParams]
    """
    The overridden price at the specified location. If this is unspecified, the modifier price is not overridden.
    The modifier becomes free of charge at the specified location, when this `price_money` field is set to 0.
    """

    sold_out: typing_extensions.NotRequired[bool]
    """
    Indicates whether the modifier is sold out at the specified location or not. As an example, for cheese (modifier) burger (item), when the modifier is sold out, it is the cheese, but not the burger, that is sold out.
    The seller can manually set this sold out status. Attempts by an application to set this attribute are ignored.
    """
