# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .team_member_wage import TeamMemberWageParams
from .error import ErrorParams


class ListTeamMemberWagesResponseParams(typing_extensions.TypedDict):
    """
    The response to a request for a set of `TeamMemberWage` objects. The response contains
    a set of `TeamMemberWage` objects.
    """

    team_member_wages: typing_extensions.NotRequired[typing.Sequence[TeamMemberWageParams]]
    """
    A page of `TeamMemberWage` results.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The value supplied in the subsequent request to fetch the next page
    of `TeamMemberWage` results.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
