# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .booking import BookingParams
from .error import ErrorParams


class ListBookingsResponseParams(typing_extensions.TypedDict):
    bookings: typing_extensions.NotRequired[typing.Sequence[BookingParams]]
    """
    The list of targeted bookings.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in the subsequent request to get the next page of the results. Stop retrieving the next page of the results when the cursor is not set.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
