# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class OrderLineItemPricingBlocklistsBlockedTaxParams(typing_extensions.TypedDict):
    """
    A tax to block from applying to a line item. The tax must be
    identified by either `tax_uid` or `tax_catalog_object_id`, but not both.
    """

    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID of the `BlockedTax` within the order.
    """

    tax_uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `uid` of the tax that should be blocked. Use this field to block
    ad hoc taxes. For catalog, taxes use the `tax_catalog_object_id` field.
    """

    tax_catalog_object_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `catalog_object_id` of the tax that should be blocked.
    Use this field to block catalog taxes. For ad hoc taxes, use the
    `tax_uid` field.
    """
