# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CardPaymentTimelineParams(typing_extensions.TypedDict):
    """
    The timeline for card payments.
    """

    authorized_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The timestamp when the payment was authorized, in RFC 3339 format.
    """

    captured_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The timestamp when the payment was captured, in RFC 3339 format.
    """

    voided_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The timestamp when the payment was voided, in RFC 3339 format.
    """
