# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_account import LoyaltyAccountParams


class SearchLoyaltyAccountsResponseParams(typing_extensions.TypedDict):
    """
    A response that includes loyalty accounts that satisfy the search criteria.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    loyalty_accounts: typing_extensions.NotRequired[typing.Sequence[LoyaltyAccountParams]]
    """
    The loyalty accounts that met the search criteria,  
    in order of creation date.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to use in a subsequent 
    request. If empty, this is the final response.
    For more information, 
    see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
