# This file was auto-generated by Fern from our API Definition.

import typing

TerminalActionActionType = typing.Union[
    typing.Literal["QR_CODE", "PING", "SAVE_CARD", "SIGNATURE", "CONFIRMATION", "RECEIPT", "DATA_COLLECTION", "SELECT"],
    typing.Any,
]
