# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class UpdateCatalogImageRequestParams(typing_extensions.TypedDict):
    idempotency_key: str
    """
    A unique string that identifies this UpdateCatalogImage request.
    Keys can be any valid string but must be unique for every UpdateCatalogImage request.
    
    See [Idempotency keys](https://developer.squareup.com/docs/build-basics/common-api-patterns/idempotency) for more information.
    """
