# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_program import LoyaltyProgramParams


class ListLoyaltyProgramsResponseParams(typing_extensions.TypedDict):
    """
    A response that contains all loyalty programs.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    programs: typing_extensions.NotRequired[typing.Sequence[LoyaltyProgramParams]]
    """
    A list of `LoyaltyProgram` for the merchant.
    """
