# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class OrderLineItemAppliedServiceChargeParams(typing_extensions.TypedDict):
    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID that identifies the applied service charge only within this order.
    """

    service_charge_uid: str
    """
    The `uid` of the service charge that the applied service charge represents. It must
    reference a service charge present in the `order.service_charges` field.
    
    This field is immutable. To change which service charges apply to a line item,
    delete and add a new `OrderLineItemAppliedServiceCharge`.
    """

    applied_money: typing_extensions.NotRequired[MoneyParams]
    """
    The amount of money applied by the service charge to the line item.
    """
