# This file was auto-generated by Fern from our API Definition.

import typing

TenderType = typing.Union[
    typing.Literal[
        "CARD",
        "CASH",
        "THIRD_PARTY_CARD",
        "SQUARE_GIFT_CARD",
        "NO_SALE",
        "BANK_ACCOUNT",
        "WALLET",
        "BUY_NOW_PAY_LATER",
        "SQUARE_ACCOUNT",
        "OTHER",
    ],
    typing.Any,
]
