# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .money import MoneyParams
from ..types.loyalty_program_accrual_rule_tax_mode import LoyaltyProgramAccrualRuleTaxMode


class LoyaltyProgramAccrualRuleVisitDataParams(typing_extensions.TypedDict):
    """
    Represents additional data for rules with the `VISIT` accrual type.
    """

    minimum_amount_money: typing_extensions.NotRequired[MoneyParams]
    """
    The minimum purchase required during the visit to quality for points.
    """

    tax_mode: LoyaltyProgramAccrualRuleTaxMode
    """
    Indicates how taxes should be treated when calculating the purchase amount to determine whether the visit qualifies for points. 
    This setting applies only if `minimum_amount_money` is specified.
    See [LoyaltyProgramAccrualRuleTaxMode](#type-loyaltyprogramaccrualruletaxmode) for possible values
    """
