# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class DisputeEvidenceFileParams(typing_extensions.TypedDict):
    """
    A file to be uploaded as dispute evidence.
    """

    filename: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The file name including the file extension. For example: "receipt.tiff".
    """

    filetype: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Dispute evidence files must be application/pdf, image/heic, image/heif, image/jpeg, image/png, or image/tiff formats.
    """
