# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class InvoiceRecipientTaxIds(UncheckedBaseModel):
    """
    Represents the tax IDs for an invoice recipient. The country of the seller account determines
    whether the corresponding `tax_ids` field is available for the customer. For more information,
    see [Invoice recipient tax IDs](https://developer.squareup.com/docs/invoices-api/overview#recipient-tax-ids).
    """

    eu_vat: typing.Optional[str] = pydantic.Field(default=None)
    """
    The EU VAT identification number for the invoice recipient. For example, `IE3426675K`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
