# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelection(UncheckedBaseModel):
    """
    A named selection for this `SELECTION`-type custom attribute definition.
    """

    uid: typing.Optional[str] = pydantic.Field(default=None)
    """
    Unique ID set by Square.
    """

    name: str = pydantic.Field()
    """
    Selection name, unique within `allowed_selections`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
