# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .catalog_info_response_limits import CatalogInfoResponseLimitsParams
from .standard_unit_description_group import StandardUnitDescriptionGroupParams


class CatalogInfoResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    limits: typing_extensions.NotRequired[CatalogInfoResponseLimitsParams]
    """
    Limits that apply to this API.
    """

    standard_unit_description_group: typing_extensions.NotRequired[StandardUnitDescriptionGroupParams]
    """
    Names and abbreviations for standard units.
    """
