# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CheckoutMerchantSettingsPaymentMethodsPaymentMethodParams(typing_extensions.TypedDict):
    """
    The settings allowed for a payment method.
    """

    enabled: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates whether the payment method is enabled for the account.
    """
