# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class MeasurementUnitCustomParams(typing_extensions.TypedDict):
    """
    The information needed to define a custom unit, provided by the seller.
    """

    name: str
    """
    The name of the custom unit, for example "bushel".
    """

    abbreviation: str
    """
    The abbreviation of the custom unit, such as "bsh" (bushel). This appears
    in the cart for the Point of Sale app, and in reports.
    """
