# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .delete_customer_response import DeleteCustomerResponse
import pydantic
from .error import Error
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BulkDeleteCustomersResponse(UncheckedBaseModel):
    """
    Defines the fields included in the response body from the
    [BulkDeleteCustomers](api-endpoint:Customers-BulkDeleteCustomers) endpoint.
    """

    responses: typing.Optional[typing.Dict[str, DeleteCustomerResponse]] = pydantic.Field(default=None)
    """
    A map of responses that correspond to individual delete requests, represented by
    key-value pairs.
    
    Each key is the customer ID that was specified for a delete request and each value
    is the corresponding response.
    If the request succeeds, the value is an empty object (`{ }`).
    If the request fails, the value contains any errors that occurred during the request.
    """

    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Any top-level errors that prevented the bulk operation from running.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
