# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class FloatNumberRangeParams(typing_extensions.TypedDict):
    """
    Specifies a decimal number range.
    """

    start_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A decimal value indicating where the range starts.
    """

    end_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A decimal value indicating where the range ends.
    """
