# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .tip_settings import TipSettingsParams


class DeviceCheckoutOptionsParams(typing_extensions.TypedDict):
    device_id: str
    """
    The unique ID of the device intended for this `TerminalCheckout`.
    A list of `DeviceCode` objects can be retrieved from the /v2/devices/codes endpoint.
    Match a `DeviceCode.device_id` value with `device_id` to get the associated device code.
    """

    skip_receipt_screen: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Instructs the device to skip the receipt screen. Defaults to false.
    """

    collect_signature: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates that signature collection is desired during checkout. Defaults to false.
    """

    tip_settings: typing_extensions.NotRequired[TipSettingsParams]
    """
    Tip-specific settings.
    """

    show_itemized_cart: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Show the itemization screen prior to taking a payment. This field is only meaningful when the
    checkout includes an order ID. Defaults to true.
    """
