# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing
from .bulk_delete_location_custom_attributes_response_location_custom_attribute_delete_response import (
    BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponseParams,
)
import typing_extensions
from .error import ErrorParams


class BulkDeleteLocationCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a [BulkDeleteLocationCustomAttributes](api-endpoint:LocationCustomAttributes-BulkDeleteLocationCustomAttributes) response,
    which contains a map of responses that each corresponds to an individual delete request.
    """

    values: typing.Dict[str, BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponseParams]
    """
    A map of responses that correspond to individual delete requests. Each response has the
    same key as the corresponding request.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
