# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class DisputedPaymentParams(typing_extensions.TypedDict):
    """
    The payment the cardholder disputed.
    """

    payment_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Square-generated unique ID of the payment being disputed.
    """
