# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.inventory_change_type import InventoryChangeType
from ..types.inventory_state import InventoryState


class BatchRetrieveInventoryChangesRequestParams(typing_extensions.TypedDict):
    catalog_object_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The filter to return results by `CatalogObject` ID.
    The filter is only applicable when set. The default value is null.
    """

    location_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The filter to return results by `Location` ID.
    The filter is only applicable when set. The default value is null.
    """

    types: typing_extensions.NotRequired[typing.Optional[typing.Sequence[InventoryChangeType]]]
    """
    The filter to return results by `InventoryChangeType` values other than `TRANSFER`.
    The default value is `[PHYSICAL_COUNT, ADJUSTMENT]`.
    """

    states: typing_extensions.NotRequired[typing.Optional[typing.Sequence[InventoryState]]]
    """
    The filter to return `ADJUSTMENT` query results by
    `InventoryState`. This filter is only applied when set.
    The default value is null.
    """

    updated_after: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The filter to return results with their `calculated_at` value
    after the given time as specified in an RFC 3339 timestamp.
    The default value is the UNIX epoch of (`1970-01-01T00:00:00Z`).
    """

    updated_before: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The filter to return results with their `created_at` or `calculated_at` value
    strictly before the given time as specified in an RFC 3339 timestamp.
    The default value is the UNIX epoch of (`1970-01-01T00:00:00Z`).
    """

    cursor: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A pagination cursor returned by a previous call to this endpoint.
    Provide this to retrieve the next set of results for the original query.
    
    See the [Pagination](https://developer.squareup.com/docs/working-with-apis/pagination) guide for more information.
    """

    limit: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The number of [records](entity:InventoryChange) to return.
    """
