# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class ClearpayDetailsParams(typing_extensions.TypedDict):
    """
    Additional details about Clearpay payments.
    """

    email_address: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Email address on the buyer's Clearpay account.
    """
