# This file was auto-generated by Fern from our API Definition.

import typing

GiftCardActivityDeactivateReason = typing.Union[
    typing.Literal["SUSPICIOUS_ACTIVITY", "UNKNOWN_REASON", "CHARGEBACK_DEACTIVATE"], typing.Any
]
