# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .catalog_object import CatalogObjectParams
from .catalog_id_mapping import CatalogIdMappingParams


class UpsertCatalogObjectResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    catalog_object: typing_extensions.NotRequired[CatalogObjectParams]
    """
    The successfully created or updated CatalogObject.
    """

    id_mappings: typing_extensions.NotRequired[typing.Sequence[CatalogIdMappingParams]]
    """
    The mapping between client and server IDs for this upsert.
    """
