# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .search_subscriptions_filter import SearchSubscriptionsFilterParams


class SearchSubscriptionsQueryParams(typing_extensions.TypedDict):
    """
    Represents a query, consisting of specified query expressions, used to search for subscriptions.
    """

    filter: typing_extensions.NotRequired[SearchSubscriptionsFilterParams]
    """
    A list of query expressions.
    """
