# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class LoyaltyProgramAccrualRuleCategoryData(UncheckedBaseModel):
    """
    Represents additional data for rules with the `CATEGORY` accrual type.
    """

    category_id: str = pydantic.Field()
    """
    The ID of the `CATEGORY` [catalog object](entity:CatalogObject) that buyers can purchase to earn
    points.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
