# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class SignatureImageParams(typing_extensions.TypedDict):
    image_type: typing_extensions.NotRequired[str]
    """
    The mime/type of the image data.
    Use `image/png;base64` for png.
    """

    data: typing_extensions.NotRequired[str]
    """
    The base64 representation of the image.
    """
