# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class VendorContactParams(typing_extensions.TypedDict):
    """
    Represents a contact of a [Vendor](entity:Vendor).
    """

    id: typing_extensions.NotRequired[str]
    """
    A unique Square-generated ID for the [VendorContact](entity:VendorContact).
    This field is required when attempting to update a [VendorContact](entity:VendorContact).
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the [VendorContact](entity:VendorContact).
    This field is required when attempting to create a [Vendor](entity:Vendor).
    """

    email_address: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The email address of the [VendorContact](entity:VendorContact).
    """

    phone_number: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The phone number of the [VendorContact](entity:VendorContact).
    """

    removed: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    The state of the [VendorContact](entity:VendorContact).
    """

    ordinal: int
    """
    The ordinal of the [VendorContact](entity:VendorContact).
    """
