# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.destination_type import DestinationType


class DestinationParams(typing_extensions.TypedDict):
    """
    Information about the destination against which the payout was made.
    """

    type: typing_extensions.NotRequired[DestinationType]
    """
    Type of the destination such as a bank account or debit card.
    See [DestinationType](#type-destinationtype) for possible values
    """

    id: typing_extensions.NotRequired[str]
    """
    Square issued unique ID (also known as the instrument ID) associated with this destination.
    """
