# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .team_member_booking_profile import TeamMemberBookingProfileParams
import typing
from .error import ErrorParams


class GetTeamMemberBookingProfileResponseParams(typing_extensions.TypedDict):
    team_member_booking_profile: typing_extensions.NotRequired[TeamMemberBookingProfileParams]
    """
    The returned team member booking profile.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
