# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .catalog_object import CatalogObjectParams


class CreateCatalogImageResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    image: typing_extensions.NotRequired[CatalogObjectParams]
    """
    The newly created `CatalogImage` including a Square-generated
    URL for the encapsulated image file.
    """
