# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .checkout_merchant_settings_payment_methods_afterpay_clearpay_eligibility_range import (
    CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeParams,
)


class CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayParams(typing_extensions.TypedDict):
    """
    The settings allowed for AfterpayClearpay.
    """

    order_eligibility_range: typing_extensions.NotRequired[
        CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeParams
    ]
    """
    Afterpay is shown as an option for order totals falling within the configured range.
    """

    item_eligibility_range: typing_extensions.NotRequired[
        CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeParams
    ]
    """
    Afterpay is shown as an option for item totals falling within the configured range.
    """

    enabled: typing_extensions.NotRequired[bool]
    """
    Indicates whether the payment method is enabled for the account.
    """
