# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.tender_square_account_details_status import TenderSquareAccountDetailsStatus


class TenderSquareAccountDetailsParams(typing_extensions.TypedDict):
    """
    Represents the details of a tender with `type` `SQUARE_ACCOUNT`.
    """

    status: typing_extensions.NotRequired[TenderSquareAccountDetailsStatus]
    """
    The Square Account payment's current state (such as `AUTHORIZED` or
    `CAPTURED`). See [TenderSquareAccountDetailsStatus](entity:TenderSquareAccountDetailsStatus)
    for possible values.
    See [Status](#type-status) for possible values
    """
