# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class TerminalRefundQuerySortParams(typing_extensions.TypedDict):
    sort_order: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The order in which results are listed.
    - `ASC` - Oldest to newest.
    - `DESC` - Newest to oldest (default).
    """
