# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .device_attributes import DeviceAttributesParams
import typing
from .component import ComponentParams
from .device_status import DeviceStatusParams


class DeviceParams(typing_extensions.TypedDict):
    id: typing_extensions.NotRequired[str]
    """
    A synthetic identifier for the device. The identifier includes a standardized prefix and
    is otherwise an opaque id generated from key device fields.
    """

    attributes: DeviceAttributesParams
    """
    A collection of DeviceAttributes representing the device.
    """

    components: typing_extensions.NotRequired[typing.Optional[typing.Sequence[ComponentParams]]]
    """
    A list of components applicable to the device.
    """

    status: typing_extensions.NotRequired[DeviceStatusParams]
    """
    The current status of the device.
    """
