# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.booking_creator_details_creator_type import BookingCreatorDetailsCreatorType


class BookingCreatorDetailsParams(typing_extensions.TypedDict):
    """
    Information about a booking creator.
    """

    creator_type: typing_extensions.NotRequired[BookingCreatorDetailsCreatorType]
    """
    The seller-accessible type of the creator of the booking.
    See [BookingCreatorDetailsCreatorType](#type-bookingcreatordetailscreatortype) for possible values
    """

    team_member_id: typing_extensions.NotRequired[str]
    """
    The ID of the team member who created the booking, when the booking creator is of the `TEAM_MEMBER` type.
    Access to this field requires seller-level permissions.
    """

    customer_id: typing_extensions.NotRequired[str]
    """
    The ID of the customer who created the booking, when the booking creator is of the `CUSTOMER` type.
    Access to this field requires seller-level permissions.
    """
