# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .afterpay_details import AfterpayDetailsParams
from .clearpay_details import ClearpayDetailsParams


class BuyNowPayLaterDetailsParams(typing_extensions.TypedDict):
    """
    Additional details about a Buy Now Pay Later payment type.
    """

    brand: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The brand used for the Buy Now Pay Later payment.
    The brand can be `AFTERPAY`, `CLEARPAY` or `UNKNOWN`.
    """

    afterpay_details: typing_extensions.NotRequired[AfterpayDetailsParams]
    """
    Details about an Afterpay payment. These details are only populated if the `brand` is
    `AFTERPAY`.
    """

    clearpay_details: typing_extensions.NotRequired[ClearpayDetailsParams]
    """
    Details about a Clearpay payment. These details are only populated if the `brand` is
    `CLEARPAY`.
    """
