# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.tender_buy_now_pay_later_details_brand import TenderBuyNowPayLaterDetailsBrand
from ..types.tender_buy_now_pay_later_details_status import TenderBuyNowPayLaterDetailsStatus


class TenderBuyNowPayLaterDetailsParams(typing_extensions.TypedDict):
    """
    Represents the details of a tender with `type` `BUY_NOW_PAY_LATER`.
    """

    buy_now_pay_later_brand: typing_extensions.NotRequired[TenderBuyNowPayLaterDetailsBrand]
    """
    The Buy Now Pay Later brand.
    See [Brand](#type-brand) for possible values
    """

    status: typing_extensions.NotRequired[TenderBuyNowPayLaterDetailsStatus]
    """
    The buy now pay later payment's current state (such as `AUTHORIZED` or
    `CAPTURED`). See [TenderBuyNowPayLaterDetailsStatus](entity:TenderBuyNowPayLaterDetailsStatus)
    for possible values.
    See [Status](#type-status) for possible values
    """
