# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class EmployeeWageParams(typing_extensions.TypedDict):
    """
    The hourly wage rate that an employee earns on a `Shift` for doing the job specified by the `title` property of this object. Deprecated at version 2020-08-26. Use [TeamMemberWage](entity:TeamMemberWage).
    """

    id: typing_extensions.NotRequired[str]
    """
    The UUID for this object.
    """

    employee_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `Employee` that this wage is assigned to.
    """

    title: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The job title that this wage relates to.
    """

    hourly_rate: typing_extensions.NotRequired[MoneyParams]
    """
    Can be a custom-set hourly wage or the calculated effective hourly
    wage based on the annual wage and hours worked per week.
    """
