# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .workweek_config import WorkweekConfigParams
from .error import ErrorParams


class ListWorkweekConfigsResponseParams(typing_extensions.TypedDict):
    """
    The response to a request for a set of `WorkweekConfig` objects. The response contains
    the requested `WorkweekConfig` objects and might contain a set of `Error` objects if
    the request resulted in errors.
    """

    workweek_configs: typing_extensions.NotRequired[typing.Sequence[WorkweekConfigParams]]
    """
    A page of `WorkweekConfig` results.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The value supplied in the subsequent request to fetch the next page of
    `WorkweekConfig` results.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
