# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .upsert_order_custom_attribute_response import UpsertOrderCustomAttributeResponseParams


class BulkUpsertOrderCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from a bulk upsert of order custom attributes.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    values: typing.Dict[str, UpsertOrderCustomAttributeResponseParams]
    """
     A map of responses that correspond to individual upsert operations for custom attributes.
    """
