# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .team_member import TeamMemberParams


class UpdateTeamMemberRequestParams(typing_extensions.TypedDict):
    """
    Represents an update request for a `TeamMember` object.
    """

    team_member: typing_extensions.NotRequired[TeamMemberParams]
    """
    The team member fields to add, change, or clear. Fields can be cleared using a null value. To update
    `wage_setting.job_assignments`, you must provide the complete list of job assignments. If needed, call
    [ListJobs](api-endpoint:Team-ListJobs) to get the required `job_id` values.
    """
