# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .checkout_location_settings import CheckoutLocationSettingsParams


class RetrieveLocationSettingsResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    location_settings: typing_extensions.NotRequired[CheckoutLocationSettingsParams]
    """
    The location settings.
    """
