# This file was auto-generated by Fern from our API Definition.

import typing

CatalogObjectType = typing.Union[
    typing.Literal[
        "ITEM",
        "IMAGE",
        "CATEGORY",
        "ITEM_VARIATION",
        "TAX",
        "DISCOUNT",
        "MODIFIER_LIST",
        "MODIFIER",
        "PRICING_RULE",
        "PRODUCT_SET",
        "TIME_PERIOD",
        "MEASUREMENT_UNIT",
        "SUBSCRIPTION_PLAN_VARIATION",
        "ITEM_OPTION",
        "ITEM_OPTION_VAL",
        "CUSTOM_ATTRIBUTE_DEFINITION",
        "QUICK_AMOUNTS_SETTINGS",
        "SUBSCRIPTION_PLAN",
        "AVAILABILITY_PERIOD",
    ],
    typing.Any,
]
