# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.device_status_category import DeviceStatusCategory


class DeviceStatusParams(typing_extensions.TypedDict):
    category: typing_extensions.NotRequired[DeviceStatusCategory]
    """
    
    See [Category](#type-category) for possible values
    """
