# This file was auto-generated by Fern from our API Definition.

import typing

BusinessAppointmentSettingsMaxAppointmentsPerDayLimitType = typing.Union[
    typing.Literal["PER_TEAM_MEMBER", "PER_LOCATION"], typing.Any
]
