# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BulkDeleteOrderCustomAttributesRequestDeleteCustomAttribute(UncheckedBaseModel):
    """
    Represents one delete within the bulk operation.
    """

    key: typing.Optional[str] = pydantic.Field(default=None)
    """
    The key of the custom attribute to delete.  This key must match the key 
    of an existing custom attribute definition.
    """

    order_id: str = pydantic.Field()
    """
    The ID of the target [order](entity:Order).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
