# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SearchOrdersSourceFilterParams(typing_extensions.TypedDict):
    """
    A filter based on order `source` information.
    """

    source_names: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    Filters by the [Source](entity:OrderSource) `name`. The filter returns any orders
    with a `source.name` that matches any of the listed source names.
    
    Max: 10 source names.
    """
