# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .order import OrderParams
from .catalog_object import CatalogObjectParams


class PaymentLinkRelatedResourcesParams(typing_extensions.TypedDict):
    orders: typing_extensions.NotRequired[typing.Optional[typing.Sequence[OrderParams]]]
    """
    The order associated with the payment link.
    """

    subscription_plans: typing_extensions.NotRequired[typing.Optional[typing.Sequence[CatalogObjectParams]]]
    """
    The subscription plan associated with the payment link.
    """
