# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .signature_image import SignatureImage
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SignatureOptions(UncheckedBaseModel):
    title: str = pydantic.Field()
    """
    The title text to display in the signature capture flow on the Terminal.
    """

    body: str = pydantic.Field()
    """
    The body text to display in the signature capture flow on the Terminal.
    """

    signature: typing.Optional[typing.List[SignatureImage]] = pydantic.Field(default=None)
    """
    An image representation of the collected signature.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
