# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class ConfirmationDecisionParams(typing_extensions.TypedDict):
    has_agreed: typing_extensions.NotRequired[bool]
    """
    The buyer's decision to the displayed terms.
    """
