# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .job import JobParams
import typing
from .error import ErrorParams


class RetrieveJobResponseParams(typing_extensions.TypedDict):
    """
    Represents a [RetrieveJob](api-endpoint:Team-RetrieveJob) response. Either `job` or `errors`
    is present in the response.
    """

    job: typing_extensions.NotRequired[JobParams]
    """
    The retrieved job.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    The errors that occurred during the request.
    """
