# This file was auto-generated by Fern from our API Definition.

import typing

ApplicationDetailsExternalSquareProduct = typing.Union[
    typing.Literal[
        "APPOINTMENTS",
        "ECOMMERCE_API",
        "INVOICES",
        "ONLINE_STORE",
        "OTHER",
        "RESTAURANTS",
        "RETAIL",
        "SQUARE_POS",
        "TERMINAL_API",
        "VIRTUAL_TERMINAL",
    ],
    typing.Any,
]
