# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .update_vendor_response import UpdateVendorResponseParams


class BatchUpdateVendorsResponseParams(typing_extensions.TypedDict):
    """
    Represents an output from a call to [BulkUpdateVendors](api-endpoint:Vendors-BulkUpdateVendors).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered when the request fails.
    """

    responses: typing_extensions.NotRequired[typing.Dict[str, UpdateVendorResponseParams]]
    """
    A set of [UpdateVendorResponse](entity:UpdateVendorResponse) objects encapsulating successfully created [Vendor](entity:Vendor)
    objects or error responses for failed attempts. The set is represented by a collection of `Vendor`-ID/`UpdateVendorResponse`-object or 
    `Vendor`-ID/error-object pairs.
    """
