# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SubscriptionTestResultParams(typing_extensions.TypedDict):
    """
    Represents the details of a webhook subscription, including notification URL,
    event types, and signature key.
    """

    id: typing_extensions.NotRequired[str]
    """
    A Square-generated unique ID for the subscription test result.
    """

    status_code: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The status code returned by the subscription notification URL.
    """

    payload: typing_extensions.NotRequired[typing.Optional[str]]
    """
    An object containing the payload of the test event. For example, a `payment.created` event.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the subscription was created, in RFC 3339 format. 
    For example, "2016-09-04T23:59:33.123Z".
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the subscription was updated, in RFC 3339 format. For example, "2016-09-04T23:59:33.123Z".
    Because a subscription test result is unique, this field is the same as the `created_at` field.
    """
