# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class OrderLineItemPricingBlocklistsBlockedDiscountParams(typing_extensions.TypedDict):
    """
    A discount to block from applying to a line item. The discount must be
    identified by either `discount_uid` or `discount_catalog_object_id`, but not both.
    """

    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID of the `BlockedDiscount` within the order.
    """

    discount_uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `uid` of the discount that should be blocked. Use this field to block
    ad hoc discounts. For catalog discounts, use the `discount_catalog_object_id` field.
    """

    discount_catalog_object_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `catalog_object_id` of the discount that should be blocked.
    Use this field to block catalog discounts. For ad hoc discounts, use the
    `discount_uid` field.
    """
