# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SearchOrdersCustomerFilterParams(typing_extensions.TypedDict):
    """
    A filter based on the order `customer_id` and any tender `customer_id`
    associated with the order. It does not filter based on the
    [FulfillmentRecipient](entity:FulfillmentRecipient) `customer_id`.
    """

    customer_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A list of customer IDs to filter by.
    
    Max: 10 customer ids.
    """
