# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .invoice import InvoiceParams
from .error import ErrorParams


class ListInvoicesResponseParams(typing_extensions.TypedDict):
    """
    Describes a `ListInvoice` response.
    """

    invoices: typing_extensions.NotRequired[typing.Sequence[InvoiceParams]]
    """
    The invoices retrieved.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    When a response is truncated, it includes a cursor that you can use in a 
    subsequent request to retrieve the next set of invoices. If empty, this is the final 
    response. 
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """
