# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .confirmation_decision import ConfirmationDecisionParams


class ConfirmationOptionsParams(typing_extensions.TypedDict):
    title: str
    """
    The title text to display in the confirmation screen flow on the Terminal.
    """

    body: str
    """
    The agreement details to display in the confirmation flow on the Terminal.
    """

    agree_button_text: str
    """
    The button text to display indicating the customer agrees to the displayed terms.
    """

    disagree_button_text: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The button text to display indicating the customer does not agree to the displayed terms.
    """

    decision: typing_extensions.NotRequired[ConfirmationDecisionParams]
    """
    The result of the buyer’s actions when presented with the confirmation screen.
    """
