# This file was auto-generated by Fern from our API Definition.

import typing

DisputeEvidenceType = typing.Union[
    typing.Literal[
        "GENERIC_EVIDENCE",
        "ONLINE_OR_APP_ACCESS_LOG",
        "AUTHORIZATION_DOCUMENTATION",
        "CANCELLATION_OR_REFUND_DOCUMENTATION",
        "CARDHOLDER_COMMUNICATION",
        "CARDHOLDER_INFORMATION",
        "PURCHASE_ACKNOWLEDGEMENT",
        "DUPLICATE_CHARGE_DOCUMENTATION",
        "PRODUCT_OR_SERVICE_DESCRIPTION",
        "RECEIPT",
        "SERVICE_RECEIVED_DOCUMENTATION",
        "PROOF_OF_DELIVERY_DOCUMENTATION",
        "RELATED_TRANSACTION_DOCUMENTATION",
        "REBUTTAL_EXPLANATION",
        "TRACKING_NUMBER",
    ],
    typing.Any,
]
