# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.data_collection_options_input_type import DataCollectionOptionsInputType
import typing_extensions
from .collected_data import CollectedDataParams


class DataCollectionOptionsParams(typing_extensions.TypedDict):
    title: str
    """
    The title text to display in the data collection flow on the Terminal.
    """

    body: str
    """
    The body text to display under the title in the data collection screen flow on the
    Terminal.
    """

    input_type: DataCollectionOptionsInputType
    """
    Represents the type of the input text.
    See [InputType](#type-inputtype) for possible values
    """

    collected_data: typing_extensions.NotRequired[CollectedDataParams]
    """
    The buyer’s input text from the data collection screen.
    """
