# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class EventTypeMetadataParams(typing_extensions.TypedDict):
    """
    Contains the metadata of a webhook event type.
    """

    event_type: typing_extensions.NotRequired[str]
    """
    The event type.
    """

    api_version_introduced: typing_extensions.NotRequired[str]
    """
    The API version at which the event type was introduced.
    """

    release_status: typing_extensions.NotRequired[str]
    """
    The release status of the event type.
    """
