# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .merchant import MerchantParams


class ListMerchantsResponseParams(typing_extensions.TypedDict):
    """
    The response object returned by the [ListMerchant](api-endpoint:Merchants-ListMerchants) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information on errors encountered during the request.
    """

    merchant: typing_extensions.NotRequired[typing.Sequence[MerchantParams]]
    """
    The requested `Merchant` entities.
    """

    cursor: typing_extensions.NotRequired[int]
    """
    If the  response is truncated, the cursor to use in next  request to fetch next set of objects.
    """
