# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogObjectReferenceParams(typing_extensions.TypedDict):
    """
    A reference to a Catalog object at a specific version. In general this is
    used as an entry point into a graph of catalog objects, where the objects exist
    at a specific version.
    """

    object_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the referenced object.
    """

    catalog_version: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The version of the object.
    """
