# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .terminal_action_query_filter import TerminalActionQueryFilter
import pydantic
from .terminal_action_query_sort import TerminalActionQuerySort
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TerminalActionQuery(UncheckedBaseModel):
    filter: typing.Optional[TerminalActionQueryFilter] = pydantic.Field(default=None)
    """
    Options for filtering returned `TerminalAction`s
    """

    sort: typing.Optional[TerminalActionQuerySort] = pydantic.Field(default=None)
    """
    Option for sorting returned `TerminalAction` objects.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
