# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment_refund import PaymentRefundParams


class GetPaymentRefundResponseParams(typing_extensions.TypedDict):
    """
    Defines the response returned by [GetRefund](api-endpoint:Refunds-GetPaymentRefund).

    Note: If there are errors processing the request, the refund field might not be
    present or it might be present in a FAILED state.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    refund: typing_extensions.NotRequired[PaymentRefundParams]
    """
    The requested `PaymentRefund`.
    """
