# This file was auto-generated by Fern from our API Definition.

import typing

V1OrderState = typing.Union[
    typing.Literal["PENDING", "OPEN", "COMPLETED", "CANCELED", "REFUNDED", "REJECTED"], typing.Any
]
