# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogItemOptionForItemParams(typing_extensions.TypedDict):
    """
     An option that can be assigned to an item.
    For example, a t-shirt item may offer a color option or a size option.
    """

    item_option_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The unique id of the item option, used to form the dimensions of the item option matrix in a specified order.
    """
