# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.timecard_sort_field import TimecardSortField
from ..types.sort_order import SortOrder


class TimecardSortParams(typing_extensions.TypedDict):
    """
    Sets the sort order of search results.
    """

    field: typing_extensions.NotRequired[TimecardSortField]
    """
    The field to sort on.
    See [TimecardSortField](#type-timecardsortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    The order in which results are returned. Defaults to DESC.
    See [SortOrder](#type-sortorder) for possible values
    """
