# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class OfflinePaymentDetailsParams(typing_extensions.TypedDict):
    """
    Details specific to offline payments.
    """

    client_created_at: typing_extensions.NotRequired[str]
    """
    The client-side timestamp of when the offline payment was created, in RFC 3339 format.
    """
