# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class RangeParams(typing_extensions.TypedDict):
    """
    The range of a number value between the specified lower and upper bounds.
    """

    min: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The lower bound of the number range. At least one of `min` or `max` must be specified.
    If unspecified, the results will have no minimum value.
    """

    max: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The upper bound of the number range. At least one of `min` or `max` must be specified.
    If unspecified, the results will have no maximum value.
    """
