# This file was auto-generated by Fern from our API Definition.

import typing

CatalogDiscountModifyTaxBasis = typing.Union[typing.Literal["MODIFY_TAX_BASIS", "DO_NOT_MODIFY_TAX_BASIS"], typing.Any]
