# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionEventSubscriptionEventType = typing.Union[
    typing.Literal[
        "START_SUBSCRIPTION",
        "PLAN_CHANGE",
        "STOP_SUBSCRIPTION",
        "DEACTIVATE_SUBSCRIPTION",
        "RESUME_SUBSCRIPTION",
        "PAUSE_SUBSCRIPTION",
        "BILLING_ANCHOR_DATE_CHANGED",
    ],
    typing.Any,
]
