# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .scheduled_shift import ScheduledShift
import pydantic
from .error import Error
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class UpdateScheduledShiftResponse(UncheckedBaseModel):
    """
    Represents an [UpdateScheduledShift](api-endpoint:Labor-UpdateScheduledShift) response.
    Either `scheduled_shift` or `errors` is present in the response.
    """

    scheduled_shift: typing.Optional[ScheduledShift] = pydantic.Field(default=None)
    """
    The updated scheduled shift. To make the changes public, call 
    [PublishScheduledShift](api-endpoint:Labor-PublishScheduledShift) or
    [BulkPublishScheduledShifts](api-endpoint:Labor-BulkPublishScheduledShifts).
    """

    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Any errors that occurred during the request.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
