# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class OrderEntryParams(typing_extensions.TypedDict):
    """
    A lightweight description of an [order](entity:Order) that is returned when
    `returned_entries` is `true` on a [SearchOrdersRequest](api-endpoint:Orders-SearchOrders).
    """

    order_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the order.
    """

    version: typing_extensions.NotRequired[int]
    """
    The version number, which is incremented each time an update is committed to the order.
    Orders that were not created through the API do not include a version number and
    therefore cannot be updated.
    
    [Read more about working with versions.](https://developer.squareup.com/docs/orders-api/manage-orders/update-orders)
    """

    location_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The location ID the order belongs to.
    """
