# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class LoyaltyEventAccumulatePromotionPointsParams(typing_extensions.TypedDict):
    """
    Provides metadata when the event `type` is `ACCUMULATE_PROMOTION_POINTS`.
    """

    loyalty_program_id: typing_extensions.NotRequired[str]
    """
    The Square-assigned ID of the [loyalty program](entity:LoyaltyProgram).
    """

    loyalty_promotion_id: typing_extensions.NotRequired[str]
    """
    The Square-assigned ID of the [loyalty promotion](entity:LoyaltyPromotion).
    """

    points: int
    """
    The number of points earned by the event.
    """

    order_id: str
    """
    The ID of the [order](entity:Order) for which the buyer earned the promotion points.
    Only applications that use the Orders API to process orders can trigger this event.
    """
