# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .timecard import TimecardParams
from .error import ErrorParams


class SearchTimecardsResponseParams(typing_extensions.TypedDict):
    """
    The response to a request for `Timecard` objects. The response contains
    the requested `Timecard` objects and might contain a set of `Error` objects if
    the request resulted in errors.
    """

    timecards: typing_extensions.NotRequired[typing.Sequence[TimecardParams]]
    """
    Timecards.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    An opaque cursor for fetching the next page.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
