# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .terminal_refund_query_filter import TerminalRefundQueryFilter
import pydantic
from .terminal_refund_query_sort import TerminalRefundQuerySort
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TerminalRefundQuery(UncheckedBaseModel):
    filter: typing.Optional[TerminalRefundQueryFilter] = pydantic.Field(default=None)
    """
    The filter for the Terminal refund query.
    """

    sort: typing.Optional[TerminalRefundQuerySort] = pydantic.Field(default=None)
    """
    The sort order for the Terminal refund query.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
