# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.subscription_pricing_type import SubscriptionPricingType
import typing
from .money import MoneyParams


class SubscriptionPricingParams(typing_extensions.TypedDict):
    """
    Describes the pricing for the subscription.
    """

    type: typing_extensions.NotRequired[SubscriptionPricingType]
    """
    RELATIVE or STATIC
    See [SubscriptionPricingType](#type-subscriptionpricingtype) for possible values
    """

    discount_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The ids of the discount catalog objects
    """

    price_money: typing_extensions.NotRequired[MoneyParams]
    """
    The price of the subscription, if STATIC
    """
