# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.device_component_details_external_power import DeviceComponentDetailsExternalPower


class DeviceComponentDetailsBatteryDetailsParams(typing_extensions.TypedDict):
    visible_percent: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The battery charge percentage as displayed on the device.
    """

    external_power: typing_extensions.NotRequired[DeviceComponentDetailsExternalPower]
    """
    The status of external_power.
    See [ExternalPower](#type-externalpower) for possible values
    """
