# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class BulkDeleteLocationCustomAttributesRequestLocationCustomAttributeDeleteRequestParams(typing_extensions.TypedDict):
    """
    Represents an individual delete request in a [BulkDeleteLocationCustomAttributes](api-endpoint:LocationCustomAttributes-BulkDeleteLocationCustomAttributes)
    request. An individual request contains an optional ID of the associated custom attribute definition
    and optional key of the associated custom attribute definition.
    """

    key: typing_extensions.NotRequired[str]
    """
    The key of the associated custom attribute definition.
    Represented as a qualified key if the requesting app is not the definition owner.
    """
