# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .scheduled_shift_filter import ScheduledShiftFilter
import pydantic
from .scheduled_shift_sort import ScheduledShiftSort
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ScheduledShiftQuery(UncheckedBaseModel):
    """
    Represents filter and sort criteria for the `query` field in a
    [SearchScheduledShifts](api-endpoint:Labor-SearchScheduledShifts) request.
    """

    filter: typing.Optional[ScheduledShiftFilter] = pydantic.Field(default=None)
    """
    Filtering options for the query.
    """

    sort: typing.Optional[ScheduledShiftSort] = pydantic.Field(default=None)
    """
    Sorting options for the query.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
