# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class ReceiptOptionsParams(typing_extensions.TypedDict):
    """
    Describes receipt action fields.
    """

    payment_id: str
    """
    The reference to the Square payment ID for the receipt.
    """

    print_only: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Instructs the device to print the receipt without displaying the receipt selection screen.
    Requires `printer_enabled` set to true.
    Defaults to false.
    """

    is_duplicate: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Identify the receipt as a reprint rather than an original receipt.
    Defaults to false.
    """
