# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SearchOrdersCustomerFilter(UncheckedBaseModel):
    """
    A filter based on the order `customer_id` and any tender `customer_id`
    associated with the order. It does not filter based on the
    [FulfillmentRecipient](entity:FulfillmentRecipient) `customer_id`.
    """

    customer_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    A list of customer IDs to filter by.
    
    Max: 10 customer ids.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
