# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment_link import PaymentLinkParams


class GetPaymentLinkResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    payment_link: typing_extensions.NotRequired[PaymentLinkParams]
    """
    The payment link that is retrieved.
    """
