# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.customer_sort_field import CustomerSortField
from ..types.sort_order import SortOrder


class CustomerSortParams(typing_extensions.TypedDict):
    """
    Represents the sorting criteria in a [search query](entity:CustomerQuery) that defines how to sort
    customer profiles returned in [SearchCustomers](api-endpoint:Customers-SearchCustomers) results.
    """

    field: typing_extensions.NotRequired[CustomerSortField]
    """
    Indicates the fields to use as the sort key, which is either the default set of fields or `created_at`.
    
    The default value is `DEFAULT`.
    See [CustomerSortField](#type-customersortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    Indicates the order in which results should be sorted based on the
    sort field value. Strings use standard alphabetic comparison
    to determine order. Strings representing numbers are sorted as strings.
    
    The default value is `ASC`.
    See [SortOrder](#type-sortorder) for possible values
    """
