# This file was auto-generated by Fern from our API Definition.

import typing

ListPaymentsRequestSortField = typing.Union[
    typing.Literal["CREATED_AT", "OFFLINE_CREATED_AT", "UPDATED_AT"], typing.Any
]
