# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AchDetails(UncheckedBaseModel):
    """
    ACH-specific details about `BANK_ACCOUNT` type payments with the `transfer_type` of `ACH`.
    """

    routing_number: typing.Optional[str] = pydantic.Field(default=None)
    """
    The routing number for the bank account.
    """

    account_number_suffix: typing.Optional[str] = pydantic.Field(default=None)
    """
    The last few digits of the bank account number.
    """

    account_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The type of the bank account performing the transfer. The account type can be `CHECKING`,
    `SAVINGS`, or `UNKNOWN`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
