# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawWebhooksClient
from .event_types.client import EventTypesClient
from .subscriptions.client import SubscriptionsClient
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawWebhooksClient
from .event_types.client import AsyncEventTypesClient
from .subscriptions.client import AsyncSubscriptionsClient


class WebhooksClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWebhooksClient(client_wrapper=client_wrapper)
        self.event_types = EventTypesClient(client_wrapper=client_wrapper)

        self.subscriptions = SubscriptionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWebhooksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWebhooksClient
        """
        return self._raw_client


class AsyncWebhooksClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWebhooksClient(client_wrapper=client_wrapper)
        self.event_types = AsyncEventTypesClient(client_wrapper=client_wrapper)

        self.subscriptions = AsyncSubscriptionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWebhooksClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWebhooksClient
        """
        return self._raw_client
