# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .job import JobParams
from .error import ErrorParams


class ListJobsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [ListJobs](api-endpoint:Team-ListJobs) response. Either `jobs` or `errors`
    is present in the response. If additional results are available, the `cursor` field is also present.
    """

    jobs: typing_extensions.NotRequired[typing.Sequence[JobParams]]
    """
    The retrieved jobs. A single paged response contains up to 100 jobs.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    An opaque cursor used to retrieve the next page of results. This field is present only
    if the request succeeded and additional results are available. For more information, see
    [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    The errors that occurred during the request.
    """
