# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionCadence = typing.Union[
    typing.Literal[
        "DAILY",
        "WEEKLY",
        "EVERY_TWO_WEEKS",
        "THIRTY_DAYS",
        "SIXTY_DAYS",
        "NINETY_DAYS",
        "MONTHLY",
        "EVERY_TWO_MONTHS",
        "QUARTERLY",
        "EVERY_FOUR_MONTHS",
        "EVERY_SIX_MONTHS",
        "ANNUAL",
        "EVERY_TWO_YEARS",
    ],
    typing.Any,
]
