# This file was auto-generated by Fern from our API Definition.

import typing

BusinessBookingProfileCustomerTimezoneChoice = typing.Union[
    typing.Literal["BUSINESS_LOCATION_TIMEZONE", "CUSTOMER_CHOICE"], typing.Any
]
