# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .custom_attribute import CustomAttributeParams
import typing
from .error import ErrorParams


class UpsertBookingCustomAttributeResponseParams(typing_extensions.TypedDict):
    """
    Represents an [UpsertBookingCustomAttribute](api-endpoint:BookingCustomAttributes-UpsertBookingCustomAttribute) response.
    Either `custom_attribute_definition` or `errors` is present in the response.
    """

    custom_attribute: typing_extensions.NotRequired[CustomAttributeParams]
    """
    The new or updated custom attribute.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
