# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.device_attributes_device_type import DeviceAttributesDeviceType
import typing_extensions
import typing


class DeviceAttributesParams(typing_extensions.TypedDict):
    type: DeviceAttributesDeviceType
    """
    The device type.
    See [DeviceType](#type-devicetype) for possible values
    """

    manufacturer: str
    """
    The maker of the device.
    """

    model: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The specific model of the device.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A seller-specified name for the device.
    """

    manufacturers_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The manufacturer-supplied identifier for the device (where available). In many cases,
    this identifier will be a serial number.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The RFC 3339-formatted value of the most recent update to the device information.
    (Could represent any field update on the device.)
    """

    version: typing_extensions.NotRequired[str]
    """
    The current version of software installed on the device.
    """

    merchant_token: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The merchant_token identifying the merchant controlling the device.
    """
