# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SaveCardOptionsParams(typing_extensions.TypedDict):
    """
    Describes save-card action fields.
    """

    customer_id: str
    """
    The square-assigned ID of the customer linked to the saved card.
    """

    card_id: typing_extensions.NotRequired[str]
    """
    The id of the created card-on-file.
    """

    reference_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    An optional user-defined reference ID that can be used to associate
    this `Card` to another entity in an external system. For example, a customer
    ID generated by a third-party system.
    """
