# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.invoice_payment_reminder_status import InvoicePaymentReminderStatus


class InvoicePaymentReminderParams(typing_extensions.TypedDict):
    """
    Describes a payment request reminder (automatic notification) that Square sends
    to the customer. You configure a reminder relative to the payment request
    `due_date`.
    """

    uid: typing_extensions.NotRequired[str]
    """
    A Square-assigned ID that uniquely identifies the reminder within the
    `InvoicePaymentRequest`.
    """

    relative_scheduled_days: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The number of days before (a negative number) or after (a positive number)
    the payment request `due_date` when the reminder is sent. For example, -3 indicates that
    the reminder should be sent 3 days before the payment request `due_date`.
    """

    message: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The reminder message.
    """

    status: typing_extensions.NotRequired[InvoicePaymentReminderStatus]
    """
    The status of the reminder.
    See [InvoicePaymentReminderStatus](#type-invoicepaymentreminderstatus) for possible values
    """

    sent_at: typing_extensions.NotRequired[str]
    """
    If sent, the timestamp when the reminder was sent, in RFC 3339 format.
    """
