# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class FulfillmentPickupDetailsCurbsidePickupDetailsParams(typing_extensions.TypedDict):
    """
    Specific details for curbside pickup.
    """

    curbside_details: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Specific details for curbside pickup, such as parking number and vehicle model.
    """

    buyer_arrived_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The [timestamp](https://developer.squareup.com/docs/build-basics/working-with-dates)
    indicating when the buyer arrived and is waiting for pickup. The timestamp must be in RFC 3339 format
    (for example, "2016-09-04T23:59:33.123Z").
    """
