# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .time_range import TimeRangeParams
from ..types.terminal_action_action_type import TerminalActionActionType


class TerminalActionQueryFilterParams(typing_extensions.TypedDict):
    device_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    `TerminalAction`s associated with a specific device. If no device is specified then all
    `TerminalAction`s for the merchant will be displayed.
    """

    created_at: typing_extensions.NotRequired[TimeRangeParams]
    """
    Time range for the beginning of the reporting period. Inclusive.
    Default value: The current time minus one day.
    Note that `TerminalAction`s are available for 30 days after creation.
    """

    status: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Filter results with the desired status of the `TerminalAction`
    Options: `PENDING`, `IN_PROGRESS`, `CANCEL_REQUESTED`, `CANCELED`, `COMPLETED`
    """

    type: typing_extensions.NotRequired[TerminalActionActionType]
    """
    Filter results with the requested ActionType.
    See [TerminalActionActionType](#type-terminalactionactiontype) for possible values
    """
