# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CustomerTaxIdsParams(typing_extensions.TypedDict):
    """
    Represents the tax ID associated with a [customer profile](entity:Customer). The corresponding `tax_ids` field is available only for customers of sellers in EU countries or the United Kingdom.
    For more information, see [Customer tax IDs](https://developer.squareup.com/docs/customers-api/what-it-does#customer-tax-ids).
    """

    eu_vat: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The EU VAT identification number for the customer. For example, `IE3426675K`. The ID can contain alphanumeric characters only.
    """
