# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .catalog_object import CatalogObjectParams


class SearchCatalogItemsResponseParams(typing_extensions.TypedDict):
    """
    Defines the response body returned from the [SearchCatalogItems](api-endpoint:Catalog-SearchCatalogItems) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    items: typing_extensions.NotRequired[typing.Sequence[CatalogObjectParams]]
    """
    Returned items matching the specified query expressions.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    Pagination token used in the next request to return more of the search result.
    """

    matched_variation_ids: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    Ids of returned item variations matching the specified query expression.
    """
