# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class AchDetailsParams(typing_extensions.TypedDict):
    """
    ACH-specific details about `BANK_ACCOUNT` type payments with the `transfer_type` of `ACH`.
    """

    routing_number: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The routing number for the bank account.
    """

    account_number_suffix: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The last few digits of the bank account number.
    """

    account_type: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The type of the bank account performing the transfer. The account type can be `CHECKING`,
    `SAVINGS`, or `UNKNOWN`.
    """
