# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class OrderRewardParams(typing_extensions.TypedDict):
    """
    Represents a reward that can be applied to an order if the necessary
    reward tier criteria are met. Rewards are created through the Loyalty API.
    """

    id: str
    """
    The identifier of the reward.
    """

    reward_tier_id: str
    """
    The identifier of the reward tier corresponding to this reward.
    """
