# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .catalog_item_food_and_beverage_details_dietary_preference import (
    CatalogItemFoodAndBeverageDetailsDietaryPreferenceParams,
)
from .catalog_item_food_and_beverage_details_ingredient import CatalogItemFoodAndBeverageDetailsIngredientParams


class CatalogItemFoodAndBeverageDetailsParams(typing_extensions.TypedDict):
    """
    The food and beverage-specific details of a `FOOD_AND_BEV` item.
    """

    calorie_count: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The calorie count (in the unit of kcal) for the `FOOD_AND_BEV` type of items.
    """

    dietary_preferences: typing_extensions.NotRequired[
        typing.Optional[typing.Sequence[CatalogItemFoodAndBeverageDetailsDietaryPreferenceParams]]
    ]
    """
    The dietary preferences for the `FOOD_AND_BEV` item.
    """

    ingredients: typing_extensions.NotRequired[
        typing.Optional[typing.Sequence[CatalogItemFoodAndBeverageDetailsIngredientParams]]
    ]
    """
    The ingredients for the `FOOD_AND_BEV` type item.
    """
