# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing


class LoyaltyEventLocationFilterParams(typing_extensions.TypedDict):
    """
    Filter events by location.
    """

    location_ids: typing.Sequence[str]
    """
    The [location](entity:Location) IDs for loyalty events to query.
    If multiple values are specified, the endpoint uses 
    a logical OR to combine them.
    """
