# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class BookingCustomAttributeDeleteResponseParams(typing_extensions.TypedDict):
    """
    Represents a response for an individual upsert request in a [BulkDeleteBookingCustomAttributes](api-endpoint:BookingCustomAttributes-BulkDeleteBookingCustomAttributes) operation.
    """

    booking_id: typing_extensions.NotRequired[str]
    """
    The ID of the [booking](entity:Booking) associated with the custom attribute.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred while processing the individual request.
    """
