# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class BulkDeleteOrderCustomAttributesRequestDeleteCustomAttributeParams(typing_extensions.TypedDict):
    """
    Represents one delete within the bulk operation.
    """

    key: typing_extensions.NotRequired[str]
    """
    The key of the custom attribute to delete.  This key must match the key 
    of an existing custom attribute definition.
    """

    order_id: str
    """
    The ID of the target [order](entity:Order).
    """
