# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class DeviceComponentDetailsCardReaderDetailsParams(typing_extensions.TypedDict):
    version: typing_extensions.NotRequired[str]
    """
    The version of the card reader.
    """
