# This file was auto-generated by Fern from our API Definition.

import typing

OrderServiceChargeTreatmentType = typing.Union[
    typing.Literal["LINE_ITEM_TREATMENT", "APPORTIONED_TREATMENT"], typing.Any
]
