# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.subscription_event_info_code import SubscriptionEventInfoCode


class SubscriptionEventInfoParams(typing_extensions.TypedDict):
    """
    Provides information about the subscription event.
    """

    detail: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A human-readable explanation for the event.
    """

    code: typing_extensions.NotRequired[SubscriptionEventInfoCode]
    """
    An info code indicating the subscription event that occurred.
    See [InfoCode](#type-infocode) for possible values
    """
