# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment import PaymentParams


class ListPaymentsResponseParams(typing_extensions.TypedDict):
    """
    Defines the response returned by [ListPayments](api-endpoint:Payments-ListPayments).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    payments: typing_extensions.NotRequired[typing.Sequence[PaymentParams]]
    """
    The requested list of payments.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in a subsequent request. If empty,
    this is the final response.
    
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
