# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class PaymentBalanceActivityFeeDetailParams(typing_extensions.TypedDict):
    payment_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the payment associated with this activity
    This will only be populated when a principal LedgerEntryToken is also populated.
    If the fee is independent (there is no principal LedgerEntryToken) then this will likely not
    be populated.
    """
