# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BulkDeleteMerchantCustomAttributesRequestMerchantCustomAttributeDeleteRequest(UncheckedBaseModel):
    """
    Represents an individual delete request in a [BulkDeleteMerchantCustomAttributes](api-endpoint:MerchantCustomAttributes-BulkDeleteMerchantCustomAttributes)
    request. An individual request contains an optional ID of the associated custom attribute definition
    and optional key of the associated custom attribute definition.
    """

    key: typing.Optional[str] = pydantic.Field(default=None)
    """
    The key of the associated custom attribute definition.
    Represented as a qualified key if the requesting app is not the definition owner.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
