# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementUnitTime = typing.Union[
    typing.Literal["GENERIC_MILLISECOND", "GENERIC_SECOND", "GENERIC_MINUTE", "GENERIC_HOUR", "GENERIC_DAY"], typing.Any
]
