# This file was auto-generated by Fern from our API Definition.

import typing

TenderBuyNowPayLaterDetailsStatus = typing.Union[
    typing.Literal["AUTHORIZED", "CAPTURED", "VOIDED", "FAILED"], typing.Any
]
