# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .timecard_filter import TimecardFilter
import pydantic
from .timecard_sort import TimecardSort
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TimecardQuery(UncheckedBaseModel):
    """
    The parameters of a `Timecard` search query, which includes filter and sort options.
    """

    filter: typing.Optional[TimecardFilter] = pydantic.Field(default=None)
    """
    Query filter options.
    """

    sort: typing.Optional[TimecardSort] = pydantic.Field(default=None)
    """
    Sort order details.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
