# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .get_booking_response import GetBookingResponseParams
from .error import ErrorParams


class BulkRetrieveBookingsResponseParams(typing_extensions.TypedDict):
    """
    Response payload for bulk retrieval of bookings.
    """

    bookings: typing_extensions.NotRequired[typing.Dict[str, GetBookingResponseParams]]
    """
    Requested bookings returned as a map containing `booking_id` as the key and `RetrieveBookingResponse` as the value.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
