# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .team_member import TeamMemberParams


class CreateTeamMemberRequestParams(typing_extensions.TypedDict):
    """
    Represents a create request for a `TeamMember` object.
    """

    idempotency_key: typing_extensions.NotRequired[str]
    """
    A unique string that identifies this `CreateTeamMember` request.
    Keys can be any valid string, but must be unique for every request.
    For more information, see [Idempotency](https://developer.squareup.com/docs/build-basics/common-api-patterns/idempotency).
    
    The minimum length is 1 and the maximum length is 45.
    """

    team_member: typing_extensions.NotRequired[TeamMemberParams]
    """
    **Required** The data used to create the `TeamMember` object. If you include `wage_setting`, you must provide
    `job_id` for each job assignment. To get job IDs, call [ListJobs](api-endpoint:Team-ListJobs).
    """
