# This file was auto-generated by Fern from our API Definition.

import typing

OrderServiceChargeCalculationPhase = typing.Union[
    typing.Literal["SUBTOTAL_PHASE", "TOTAL_PHASE", "APPORTIONED_PERCENTAGE_PHASE", "APPORTIONED_AMOUNT_PHASE"],
    typing.Any,
]
