# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .subscription import SubscriptionParams
from .subscription_action import SubscriptionActionParams


class CancelSubscriptionResponseParams(typing_extensions.TypedDict):
    """
    Defines output parameters in a response from the
    [CancelSubscription](api-endpoint:Subscriptions-CancelSubscription) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered during the request.
    """

    subscription: typing_extensions.NotRequired[SubscriptionParams]
    """
    The specified subscription scheduled for cancellation according to the action created by the request.
    """

    actions: typing_extensions.NotRequired[typing.Sequence[SubscriptionActionParams]]
    """
    A list of a single `CANCEL` action scheduled for the subscription.
    """
