# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class BulkPublishScheduledShiftsDataParams(typing_extensions.TypedDict):
    """
    Represents options for an individual publish request in a
    [BulkPublishScheduledShifts](api-endpoint:Labor-BulkPublishScheduledShifts)
    operation, provided as the value in a key-value pair.
    """

    version: typing_extensions.NotRequired[int]
    """
    The current version of the scheduled shift, used to enable [optimistic concurrency](https://developer.squareup.com/docs/build-basics/common-api-patterns/optimistic-concurrency)
    control. If the provided version doesn't match the server version, the request fails.
    If omitted, Square executes a blind write, potentially overwriting data from another publish request.
    """
