# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .customer_custom_attribute_filter import CustomerCustomAttributeFilterParams


class CustomerCustomAttributeFiltersParams(typing_extensions.TypedDict):
    """
    The custom attribute filters in a set of [customer filters](entity:CustomerFilter) used in a search query. Use this filter
    to search based on [custom attributes](entity:CustomAttribute) that are assigned to customer profiles. For more information, see
    [Search by custom attribute](https://developer.squareup.com/docs/customers-api/use-the-api/search-customers#search-by-custom-attribute).
    """

    filters: typing_extensions.NotRequired[typing.Optional[typing.Sequence[CustomerCustomAttributeFilterParams]]]
    """
    The custom attribute filters. Each filter must specify `key` and include the `filter` field with a type-specific filter,
    the `updated_at` field, or both. The provided keys must be unique within the list of custom attribute filters.
    """
