# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class AcceptedPaymentMethodsParams(typing_extensions.TypedDict):
    apple_pay: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether Apple Pay is accepted at checkout.
    """

    google_pay: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether Google Pay is accepted at checkout.
    """

    cash_app_pay: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether Cash App Pay is accepted at checkout.
    """

    afterpay_clearpay: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether Afterpay/Clearpay is accepted at checkout.
    """
