# This file was auto-generated by Fern from our API Definition.

import typing

LoyaltyEventType = typing.Union[
    typing.Literal[
        "ACCUMULATE_POINTS",
        "CREATE_REWARD",
        "REDEEM_REWARD",
        "DELETE_REWARD",
        "ADJUST_POINTS",
        "EXPIRE_POINTS",
        "OTHER",
        "ACCUMULATE_PROMOTION_POINTS",
    ],
    typing.Any,
]
