# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .error import Error
import pydantic
from .delete_order_custom_attribute_response import DeleteOrderCustomAttributeResponse
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BulkDeleteOrderCustomAttributesResponse(UncheckedBaseModel):
    """
    Represents a response from deleting one or more order custom attributes.
    """

    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Any errors that occurred during the request.
    """

    values: typing.Dict[str, DeleteOrderCustomAttributeResponse] = pydantic.Field()
    """
     A map of responses that correspond to individual delete requests. Each response has the same ID 
    as the corresponding request and contains either a `custom_attribute` or an `errors` field.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
