# This file was auto-generated by Fern from our API Definition.

import typing

BusinessAppointmentSettingsCancellationPolicy = typing.Union[
    typing.Literal["CANCELLATION_TREATED_AS_NO_SHOW", "CUSTOM_POLICY"], typing.Any
]
