# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .loyalty_event_filter import LoyaltyEventFilterParams


class LoyaltyEventQueryParams(typing_extensions.TypedDict):
    """
    Represents a query used to search for loyalty events.
    """

    filter: typing_extensions.NotRequired[LoyaltyEventFilterParams]
    """
    The query filter criteria.
    """
