# This file was auto-generated by Fern from our API Definition.

import typing

GiftCardActivityAdjustIncrementReason = typing.Union[
    typing.Literal["COMPLIMENTARY", "SUPPORT_ISSUE", "TRANSACTION_VOIDED"], typing.Any
]
