# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .payment_link import PaymentLinkParams


class ListPaymentLinksResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """

    payment_links: typing_extensions.NotRequired[typing.Sequence[PaymentLinkParams]]
    """
    The list of payment links.
    """

    cursor: typing_extensions.NotRequired[str]
    """
      When a response is truncated, it includes a cursor that you can use in a subsequent request
    to retrieve the next set of gift cards. If a cursor is not present, this is the final response.
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
