# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .error import Error
import pydantic
from .bank_account import BankAccount
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ListBankAccountsResponse(UncheckedBaseModel):
    """
    Response object returned by ListBankAccounts.
    """

    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Information on errors encountered during the request.
    """

    bank_accounts: typing.Optional[typing.List[BankAccount]] = pydantic.Field(default=None)
    """
    List of BankAccounts associated with this account.
    """

    cursor: typing.Optional[str] = pydantic.Field(default=None)
    """
    When a response is truncated, it includes a cursor that you can 
    use in a subsequent request to fetch next set of bank accounts.
    If empty, this is the final response.
    
    For more information, see [Pagination](https://developer.squareup.com/docs/working-with-apis/pagination).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
