# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.application_details_external_square_product import ApplicationDetailsExternalSquareProduct
import typing


class ApplicationDetailsParams(typing_extensions.TypedDict):
    """
    Details about the application that took the payment.
    """

    square_product: typing_extensions.NotRequired[ApplicationDetailsExternalSquareProduct]
    """
    The Square product, such as Square Point of Sale (POS), 
    Square Invoices, or Square Virtual Terminal.
    See [ExternalSquareProduct](#type-externalsquareproduct) for possible values
    """

    application_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The Square ID assigned to the application used to take the payment. 
    Application developers can use this information to identify payments that 
    their application processed. 
    For example, if a developer uses a custom application to process payments, 
    this field contains the application ID from the Developer Dashboard. 
    If a seller uses a [Square App Marketplace](https://developer.squareup.com/docs/app-marketplace) 
    application to process payments, the field contains the corresponding application ID.
    """
