# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class LoyaltyEventLocationFilter(UncheckedBaseModel):
    """
    Filter events by location.
    """

    location_ids: typing.List[str] = pydantic.Field()
    """
    The [location](entity:Location) IDs for loyalty events to query.
    If multiple values are specified, the endpoint uses 
    a logical OR to combine them.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
