# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .time_range import TimeRange
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SearchEventsFilter(UncheckedBaseModel):
    """
    Criteria to filter events by.
    """

    event_types: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter events by event types.
    """

    merchant_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter events by merchant.
    """

    location_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter events by location.
    """

    created_at: typing.Optional[TimeRange] = pydantic.Field(default=None)
    """
    Filter events by when they were created.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
