# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawCashDrawersClient
from .shifts.client import ShiftsClient
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawCashDrawersClient
from .shifts.client import AsyncShiftsClient


class CashDrawersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawCashDrawersClient(client_wrapper=client_wrapper)
        self.shifts = ShiftsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawCashDrawersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawCashDrawersClient
        """
        return self._raw_client


class AsyncCashDrawersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawCashDrawersClient(client_wrapper=client_wrapper)
        self.shifts = AsyncShiftsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawCashDrawersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawCashDrawersClient
        """
        return self._raw_client
