# This file was auto-generated by Fern from our API Definition.

import typing

BankAccountType = typing.Union[
    typing.Literal["CHECKING", "SAVINGS", "INVESTMENT", "OTHER", "BUSINESS_CHECKING"], typing.Any
]
