# This file was auto-generated by Fern from our API Definition.

import typing

FulfillmentState = typing.Union[
    typing.Literal["PROPOSED", "RESERVED", "PREPARED", "COMPLETED", "CANCELED", "FAILED"], typing.Any
]
