# This file was auto-generated by Fern from our API Definition.

import typing

CatalogItemFoodAndBeverageDetailsDietaryPreferenceStandardDietaryPreference = typing.Union[
    typing.Literal["DAIRY_FREE", "GLUTEN_FREE", "HALAL", "KOSHER", "NUT_FREE", "VEGAN", "VEGETARIAN"], typing.Any
]
