# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .cash_app_details import CashAppDetailsParams


class DigitalWalletDetailsParams(typing_extensions.TypedDict):
    """
    Additional details about `WALLET` type payments. Contains only non-confidential information.
    """

    status: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The status of the `WALLET` payment. The status can be `AUTHORIZED`, `CAPTURED`, `VOIDED`, or
    `FAILED`.
    """

    brand: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The brand used for the `WALLET` payment. The brand can be `CASH_APP`, `PAYPAY`, `ALIPAY`,
    `RAKUTEN_PAY`, `AU_PAY`, `D_BARAI`, `MERPAY`, `WECHAT_PAY` or `UNKNOWN`.
    """

    cash_app_details: typing_extensions.NotRequired[CashAppDetailsParams]
    """
    Brand-specific details for payments with the `brand` of `CASH_APP`.
    """
