# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class CheckoutLocationSettingsTippingParams(typing_extensions.TypedDict):
    percentages: typing_extensions.NotRequired[typing.Optional[typing.Sequence[int]]]
    """
    Set three custom percentage amounts that buyers can select at checkout. If Smart Tip is enabled, this only applies to transactions totaling $10 or more.
    """

    smart_tipping_enabled: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Enables Smart Tip Amounts. If Smart Tip Amounts is enabled, tipping works as follows:
    If a transaction is less than $10, the available tipping options include No Tip, $1, $2, or $3.
    If a transaction is $10 or more, the available tipping options include No Tip, 15%, 20%, or 25%. 
    You can set custom percentage amounts with the `percentages` field.
    """

    default_percent: typing_extensions.NotRequired[typing.Optional[int]]
    """
    Set the pre-selected percentage amounts that appear at checkout. If Smart Tip is enabled, this only applies to transactions totaling $10 or more.
    """

    smart_tips: typing_extensions.NotRequired[typing.Optional[typing.Sequence[MoneyParams]]]
    """
    Show the Smart Tip Amounts for this location.
    """

    default_smart_tip: typing_extensions.NotRequired[MoneyParams]
    """
    Set the pre-selected whole amount that appears at checkout when Smart Tip is enabled and the transaction amount is less than $10.
    """
