# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class DeviceDetailsParams(typing_extensions.TypedDict):
    """
    Details about the device that took the payment.
    """

    device_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The Square-issued ID of the device.
    """

    device_installation_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The Square-issued installation ID for the device.
    """

    device_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the device set by the seller.
    """
