# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .address import AddressParams


class PrePopulatedDataParams(typing_extensions.TypedDict):
    """
    Describes buyer data to prepopulate in the payment form.
    For more information,
    see [Optional Checkout Configurations](https://developer.squareup.com/docs/checkout-api/optional-checkout-configurations).
    """

    buyer_email: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The buyer email to prepopulate in the payment form.
    """

    buyer_phone_number: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The buyer phone number to prepopulate in the payment form.
    """

    buyer_address: typing_extensions.NotRequired[AddressParams]
    """
    The buyer address to prepopulate in the payment form.
    """
