# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .scheduled_shift import ScheduledShiftParams
import typing
from .error import ErrorParams


class CreateScheduledShiftResponseParams(typing_extensions.TypedDict):
    """
    Represents a [CreateScheduledShift](api-endpoint:Labor-CreateScheduledShift) response.
    Either `scheduled_shift` or `errors` is present in the response.
    """

    scheduled_shift: typing_extensions.NotRequired[ScheduledShiftParams]
    """
    The new scheduled shift. To make the shift public, call 
    [PublishScheduledShift](api-endpoint:Labor-PublishScheduledShift) or
    [BulkPublishScheduledShifts](api-endpoint:Labor-BulkPublishScheduledShifts).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
