# This file was auto-generated by Fern from our API Definition.

import typing

V1TenderEntryMethod = typing.Union[
    typing.Literal["MANUAL", "SCANNED", "SQUARE_CASH", "SQUARE_WALLET", "SWIPED", "WEB_FORM", "OTHER"], typing.Any
]
