# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LoyaltyPromotionIncentivePointsAdditionDataParams(typing_extensions.TypedDict):
    """
    Represents the metadata for a `POINTS_ADDITION` type of [loyalty promotion incentive](entity:LoyaltyPromotionIncentive).
    """

    points_addition: int
    """
    The number of additional points to earn each time the promotion is triggered. For example,
    suppose a purchase qualifies for 5 points from the base loyalty program. If the purchase also
    qualifies for a `POINTS_ADDITION` promotion incentive with a `points_addition` of 3, the buyer
    earns a total of 8 points (5 program points + 3 promotion points = 8 points).
    """
