# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CheckoutLocationSettingsPolicyParams(typing_extensions.TypedDict):
    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID to identify the policy when making changes. You must set the UID for policy updates, but it’s optional when setting new policies.
    """

    title: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The title of the policy. This is required when setting the description, though you can update it in a different request.
    """

    description: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The description of the policy.
    """
