# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CatalogModifierOverride(UncheckedBaseModel):
    """
    Options to control how to override the default behavior of the specified modifier.
    """

    modifier_id: str = pydantic.Field()
    """
    The ID of the `CatalogModifier` whose default behavior is being overridden.
    """

    on_by_default: typing.Optional[bool] = pydantic.Field(default=None)
    """
    __Deprecated__: Use `on_by_default_override` instead.
    """

    hidden_online_override: typing.Optional[typing.Optional[typing.Any]] = None
    on_by_default_override: typing.Optional[typing.Optional[typing.Any]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
