# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .loyalty_account_mapping import LoyaltyAccountMappingParams


class SearchLoyaltyAccountsRequestLoyaltyAccountQueryParams(typing_extensions.TypedDict):
    """
    The search criteria for the loyalty accounts.
    """

    mappings: typing_extensions.NotRequired[typing.Optional[typing.Sequence[LoyaltyAccountMappingParams]]]
    """
    The set of mappings to use in the loyalty account search.  
    
    This cannot be combined with `customer_ids`.  
    
    Max: 30 mappings
    """

    customer_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The set of customer IDs to use in the loyalty account search.  
    
    This cannot be combined with `mappings`.  
    
    Max: 30 customer IDs
    """
