# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .order import OrderParams


class PayOrderResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of a request to the
    [PayOrder](api-endpoint:Orders-PayOrder) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    order: typing_extensions.NotRequired[OrderParams]
    """
    The paid, updated [order](entity:Order).
    """
