# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .scheduled_shift import ScheduledShiftParams
from .error import ErrorParams


class SearchScheduledShiftsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [SearchScheduledShifts](api-endpoint:Labor-SearchScheduledShifts) response.
    Either `scheduled_shifts` or `errors` is present in the response.
    """

    scheduled_shifts: typing_extensions.NotRequired[typing.Sequence[ScheduledShiftParams]]
    """
    A paginated list of scheduled shifts that match the query conditions.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor used to retrieve the next page of results. This field is present
    only if additional results are available.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
