# This file was auto-generated by Fern from our API Definition.

import typing

CatalogQuickAmountType = typing.Union[typing.Literal["QUICK_AMOUNT_TYPE_MANUAL", "QUICK_AMOUNT_TYPE_AUTO"], typing.Any]
