# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LoyaltyEventOrderFilterParams(typing_extensions.TypedDict):
    """
    Filter events by the order associated with the event.
    """

    order_id: str
    """
    The ID of the [order](entity:Order) associated with the event.
    """
