# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .timecard_filter import TimecardFilterParams
from .timecard_sort import TimecardSortParams


class TimecardQueryParams(typing_extensions.TypedDict):
    """
    The parameters of a `Timecard` search query, which includes filter and sort options.
    """

    filter: typing_extensions.NotRequired[TimecardFilterParams]
    """
    Query filter options.
    """

    sort: typing_extensions.NotRequired[TimecardSortParams]
    """
    Sort order details.
    """
