# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .money import Money
import pydantic
from .gift_card_activity_adjust_decrement_reason import GiftCardActivityAdjustDecrementReason
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GiftCardActivityAdjustDecrement(UncheckedBaseModel):
    """
    Represents details about an `ADJUST_DECREMENT` [gift card activity type](entity:GiftCardActivityType).
    """

    amount_money: Money = pydantic.Field()
    """
    The amount deducted from the gift card balance. This value is a positive integer.
    """

    reason: GiftCardActivityAdjustDecrementReason = pydantic.Field()
    """
    The reason the gift card balance was adjusted.
    See [Reason](#type-reason) for possible values
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
