# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .error import Error
import pydantic
from .customer_segment import CustomerSegment
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ListCustomerSegmentsResponse(UncheckedBaseModel):
    """
    Defines the fields that are included in the response body for requests to the `ListCustomerSegments` endpoint.

    Either `errors` or `segments` is present in a given response (never both).
    """

    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Any errors that occurred during the request.
    """

    segments: typing.Optional[typing.List[CustomerSegment]] = pydantic.Field(default=None)
    """
    The list of customer segments belonging to the associated Square account.
    """

    cursor: typing.Optional[str] = pydantic.Field(default=None)
    """
    A pagination cursor to be used in subsequent calls to `ListCustomerSegments`
    to retrieve the next set of query results. The cursor is only present if the request succeeded and
    additional results are available.
    
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
