# This file was auto-generated by Fern from our API Definition.

import typing

BusinessAppointmentSettingsAlignmentTime = typing.Union[
    typing.Literal["SERVICE_DURATION", "QUARTER_HOURLY", "HALF_HOURLY", "HOURLY"], typing.Any
]
