# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .booking_custom_attribute_delete_response import BookingCustomAttributeDeleteResponseParams
from .error import ErrorParams


class BulkDeleteBookingCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a [BulkDeleteBookingCustomAttributes](api-endpoint:BookingCustomAttributes-BulkDeleteBookingCustomAttributes) response,
    which contains a map of responses that each corresponds to an individual delete request.
    """

    values: typing_extensions.NotRequired[typing.Dict[str, BookingCustomAttributeDeleteResponseParams]]
    """
    A map of responses that correspond to individual delete requests. Each response has the
    same ID as the corresponding request and contains `booking_id` and  `errors` field.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
