# This file was auto-generated by Fern from our API Definition.

import typing

DeviceComponentDetailsExternalPower = typing.Union[
    typing.Literal["AVAILABLE_CHARGING", "AVAILABLE_NOT_IN_USE", "UNAVAILABLE", "AVAILABLE_INSUFFICIENT"], typing.Any
]
