# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.vendor_status import VendorStatus


class SearchVendorsRequestFilterParams(typing_extensions.TypedDict):
    """
    Defines supported query expressions to search for vendors by.
    """

    name: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The names of the [Vendor](entity:Vendor) objects to retrieve.
    """

    status: typing_extensions.NotRequired[typing.Optional[typing.Sequence[VendorStatus]]]
    """
    The statuses of the [Vendor](entity:Vendor) objects to retrieve.
    See [VendorStatus](#type-vendorstatus) for possible values
    """
