# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementUnitWeight = typing.Union[
    typing.Literal[
        "IMPERIAL_WEIGHT_OUNCE",
        "IMPERIAL_POUND",
        "IMPERIAL_STONE",
        "METRIC_MILLIGRAM",
        "METRIC_GRAM",
        "METRIC_KILOGRAM",
    ],
    typing.Any,
]
