# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .appointment_segment import AppointmentSegmentParams


class AvailabilityParams(typing_extensions.TypedDict):
    """
    Defines an appointment slot that encapsulates the appointment segments, location and starting time available for booking.
    """

    start_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The RFC 3339 timestamp specifying the beginning time of the slot available for booking.
    """

    location_id: typing_extensions.NotRequired[str]
    """
    The ID of the location available for booking.
    """

    appointment_segments: typing_extensions.NotRequired[typing.Optional[typing.Sequence[AppointmentSegmentParams]]]
    """
    The list of appointment segments available for booking
    """
