# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .custom_attribute_definition import CustomAttributeDefinitionParams
from .error import ErrorParams


class ListCustomerCustomAttributeDefinitionsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [ListCustomerCustomAttributeDefinitions](api-endpoint:CustomerCustomAttributes-ListCustomerCustomAttributeDefinitions) response.
    Either `custom_attribute_definitions`, an empty object, or `errors` is present in the response.
    If additional results are available, the `cursor` field is also present along with `custom_attribute_definitions`.
    """

    custom_attribute_definitions: typing_extensions.NotRequired[typing.Sequence[CustomAttributeDefinitionParams]]
    """
    The retrieved custom attribute definitions. If no custom attribute definitions are found,
    Square returns an empty object (`{}`).
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The cursor to provide in your next call to this endpoint to retrieve the next page of
    results for your original request. This field is present only if the request succeeded and
    additional results are available. For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
