# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.catalog_quick_amount_type import CatalogQuickAmountType
from .money import MoneyParams
import typing_extensions
import typing


class CatalogQuickAmountParams(typing_extensions.TypedDict):
    """
    Represents a Quick Amount in the Catalog.
    """

    type: CatalogQuickAmountType
    """
    Represents the type of the Quick Amount.
    See [CatalogQuickAmountType](#type-catalogquickamounttype) for possible values
    """

    amount: MoneyParams
    """
    Represents the actual amount of the Quick Amount with Money type.
    """

    score: typing_extensions.NotRequired[typing.Optional[int]]
    """
    Describes the ranking of the Quick Amount provided by machine learning model, in the range [0, 100].
    MANUAL type amount will always have score = 100.
    """

    ordinal: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The order in which this Quick Amount should be displayed.
    """
