# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class LoyaltyAccountMappingParams(typing_extensions.TypedDict):
    """
    Represents the mapping that associates a loyalty account with a buyer.

    Currently, a loyalty account can only be mapped to a buyer by phone number. For more information, see
    [Loyalty Overview](https://developer.squareup.com/docs/loyalty/overview).
    """

    id: typing_extensions.NotRequired[str]
    """
    The Square-assigned ID of the mapping.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the mapping was created, in RFC 3339 format.
    """

    phone_number: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The phone number of the buyer, in E.164 format. For example, "+14155551111".
    """
