# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .vendor_status import VendorStatus
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SearchVendorsRequestFilter(UncheckedBaseModel):
    """
    Defines supported query expressions to search for vendors by.
    """

    name: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The names of the [Vendor](entity:Vendor) objects to retrieve.
    """

    status: typing.Optional[typing.List[VendorStatus]] = pydantic.Field(default=None)
    """
    The statuses of the [Vendor](entity:Vendor) objects to retrieve.
    See [VendorStatus](#type-vendorstatus) for possible values
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
