# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .money import Money
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class QuickPay(UncheckedBaseModel):
    """
    Describes an ad hoc item and price to generate a quick pay checkout link.
    For more information,
    see [Quick Pay Checkout](https://developer.squareup.com/docs/checkout-api/quick-pay-checkout).
    """

    name: str = pydantic.Field()
    """
    The ad hoc item name. In the resulting `Order`, this name appears as the line item name.
    """

    price_money: Money = pydantic.Field()
    """
    The price of the item.
    """

    location_id: str = pydantic.Field()
    """
    The ID of the business location the checkout is associated with.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
