# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SignatureImage(UncheckedBaseModel):
    image_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The mime/type of the image data.
    Use `image/png;base64` for png.
    """

    data: typing.Optional[str] = pydantic.Field(default=None)
    """
    The base64 representation of the image.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
