# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SearchSubscriptionsFilterParams(typing_extensions.TypedDict):
    """
    Represents a set of query expressions (filters) to narrow the scope of targeted subscriptions returned by
    the [SearchSubscriptions](api-endpoint:Subscriptions-SearchSubscriptions) endpoint.
    """

    customer_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A filter to select subscriptions based on the subscribing customer IDs.
    """

    location_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A filter to select subscriptions based on the location.
    """

    source_names: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A filter to select subscriptions based on the source application.
    """
