# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .job_assignment import JobAssignmentParams


class WageSettingParams(typing_extensions.TypedDict):
    """
    Represents information about the overtime exemption status, job assignments, and compensation
    for a [team member](entity:TeamMember).
    """

    team_member_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the team member associated with the wage setting.
    """

    job_assignments: typing_extensions.NotRequired[typing.Optional[typing.Sequence[JobAssignmentParams]]]
    """
    **Required** The ordered list of jobs that the team member is assigned to.
    The first job assignment is considered the team member's primary job.
    """

    is_overtime_exempt: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether the team member is exempt from the overtime rules of the seller's country.
    """

    version: typing_extensions.NotRequired[int]
    """
    **Read only** Used for resolving concurrency issues. The request fails if the version
    provided does not match the server version at the time of the request. If not provided,
    Square executes a blind write, potentially overwriting data from another write. For more information,
    see [optimistic concurrency](https://developer.squareup.com/docs/working-with-apis/optimistic-concurrency).
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the wage setting was created, in RFC 3339 format.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the wage setting was last updated, in RFC 3339 format.
    """
