# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .standard_unit_description import StandardUnitDescriptionParams


class StandardUnitDescriptionGroupParams(typing_extensions.TypedDict):
    """
    Group of standard measurement units.
    """

    standard_unit_descriptions: typing_extensions.NotRequired[
        typing.Optional[typing.Sequence[StandardUnitDescriptionParams]]
    ]
    """
    List of standard (non-custom) measurement units in this description group.
    """

    language_code: typing_extensions.NotRequired[typing.Optional[str]]
    """
    IETF language tag.
    """
