# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .order import OrderParams
import typing
from .error import ErrorParams


class CalculateOrderResponseParams(typing_extensions.TypedDict):
    order: typing_extensions.NotRequired[OrderParams]
    """
    The calculated version of the order provided in the request.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
