# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing


class CatalogQueryTextParams(typing_extensions.TypedDict):
    """
    The query filter to return the search result whose searchable attribute values contain all of the specified keywords or tokens, independent of the token order or case.
    """

    keywords: typing.Sequence[str]
    """
    A list of 1, 2, or 3 search keywords. Keywords with fewer than 3 alphanumeric characters are ignored.
    """
