# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .bulk_upsert_merchant_custom_attributes_response_merchant_custom_attribute_upsert_response import (
    BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponseParams,
)
from .error import ErrorParams


class BulkUpsertMerchantCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a [BulkUpsertMerchantCustomAttributes](api-endpoint:MerchantCustomAttributes-BulkUpsertMerchantCustomAttributes) response,
    which contains a map of responses that each corresponds to an individual upsert request.
    """

    values: typing_extensions.NotRequired[
        typing.Dict[str, BulkUpsertMerchantCustomAttributesResponseMerchantCustomAttributeUpsertResponseParams]
    ]
    """
    A map of responses that correspond to individual upsert requests. Each response has the
    same ID as the corresponding request and contains either a `merchant_id` and `custom_attribute` or an `errors` field.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
