# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .scheduled_shift_filter import ScheduledShiftFilterParams
from .scheduled_shift_sort import ScheduledShiftSortParams


class ScheduledShiftQueryParams(typing_extensions.TypedDict):
    """
    Represents filter and sort criteria for the `query` field in a
    [SearchScheduledShifts](api-endpoint:Labor-SearchScheduledShifts) request.
    """

    filter: typing_extensions.NotRequired[ScheduledShiftFilterParams]
    """
    Filtering options for the query.
    """

    sort: typing_extensions.NotRequired[ScheduledShiftSortParams]
    """
    Sorting options for the query.
    """
