# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .standard_unit_description import StandardUnitDescription
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class StandardUnitDescriptionGroup(UncheckedBaseModel):
    """
    Group of standard measurement units.
    """

    standard_unit_descriptions: typing.Optional[typing.List[StandardUnitDescription]] = pydantic.Field(default=None)
    """
    List of standard (non-custom) measurement units in this description group.
    """

    language_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    IETF language tag.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
