# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .error import Error
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class DeleteCatalogObjectResponse(UncheckedBaseModel):
    errors: typing.Optional[typing.List[Error]] = pydantic.Field(default=None)
    """
    Any errors that occurred during the request.
    """

    deleted_object_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The IDs of all catalog objects deleted by this request.
    Multiple IDs may be returned when associated objects are also deleted, for example
    a catalog item variation will be deleted (and its ID included in this field)
    when its parent catalog item is deleted.
    """

    deleted_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The database [timestamp](https://developer.squareup.com/docs/build-basics/working-with-dates)
    of this deletion in RFC 3339 format, e.g., `2016-09-04T23:59:33.123Z`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
