# This file was auto-generated by Fern from our API Definition.

import typing

Product = typing.Union[
    typing.Literal[
        "SQUARE_POS",
        "EXTERNAL_API",
        "BILLING",
        "APPOINTMENTS",
        "INVOICES",
        "ONLINE_STORE",
        "PAYROLL",
        "DASHBOARD",
        "ITEM_LIBRARY_IMPORT",
        "OTHER",
    ],
    typing.Any,
]
