# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams


class OrderRoundingAdjustmentParams(typing_extensions.TypedDict):
    """
    A rounding adjustment of the money being returned. Commonly used to apply cash rounding
    when the minimum unit of the account is smaller than the lowest physical denomination of the currency.
    """

    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID that identifies the rounding adjustment only within this order.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the rounding adjustment from the original sale order.
    """

    amount_money: typing_extensions.NotRequired[MoneyParams]
    """
    The actual rounding adjustment amount.
    """
