# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .device_code import DeviceCodeParams


class ListDeviceCodesResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    device_codes: typing_extensions.NotRequired[typing.Sequence[DeviceCodeParams]]
    """
    The queried DeviceCode.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    A pagination cursor to retrieve the next set of results for your
    original query to the endpoint. This value is present only if the request
    succeeded and additional results are available.
    
    See [Paginating results](https://developer.squareup.com/docs/working-with-apis/pagination) for more information.
    """
