# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .booking_custom_attribute_upsert_response import BookingCustomAttributeUpsertResponseParams
from .error import ErrorParams


class BulkUpsertBookingCustomAttributesResponseParams(typing_extensions.TypedDict):
    """
    Represents a [BulkUpsertBookingCustomAttributes](api-endpoint:BookingCustomAttributes-BulkUpsertBookingCustomAttributes) response,
    which contains a map of responses that each corresponds to an individual upsert request.
    """

    values: typing_extensions.NotRequired[typing.Dict[str, BookingCustomAttributeUpsertResponseParams]]
    """
    A map of responses that correspond to individual upsert requests. Each response has the
    same ID as the corresponding request and contains either a `booking_id` and `custom_attribute` or an `errors` field.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
