# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .money import MoneyParams


class OrderMoneyAmountsParams(typing_extensions.TypedDict):
    """
    A collection of various money amounts.
    """

    total_money: typing_extensions.NotRequired[MoneyParams]
    """
    The total money.
    """

    tax_money: typing_extensions.NotRequired[MoneyParams]
    """
    The money associated with taxes.
    """

    discount_money: typing_extensions.NotRequired[MoneyParams]
    """
    The money associated with discounts.
    """

    tip_money: typing_extensions.NotRequired[MoneyParams]
    """
    The money associated with tips.
    """

    service_charge_money: typing_extensions.NotRequired[MoneyParams]
    """
    The money associated with service charges.
    """
