# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.inventory_state import InventoryState


class BatchGetInventoryCountsRequestParams(typing_extensions.TypedDict):
    catalog_object_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The filter to return results by `CatalogObject` ID.
    The filter is applicable only when set.  The default is null.
    """

    location_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The filter to return results by `Location` ID.
    This filter is applicable only when set. The default is null.
    """

    updated_after: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The filter to return results with their `calculated_at` value
    after the given time as specified in an RFC 3339 timestamp.
    The default value is the UNIX epoch of (`1970-01-01T00:00:00Z`).
    """

    cursor: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A pagination cursor returned by a previous call to this endpoint.
    Provide this to retrieve the next set of results for the original query.
    
    See the [Pagination](https://developer.squareup.com/docs/working-with-apis/pagination) guide for more information.
    """

    states: typing_extensions.NotRequired[typing.Optional[typing.Sequence[InventoryState]]]
    """
    The filter to return results by `InventoryState`. The filter is only applicable when set.
    Ignored are untracked states of `NONE`, `SOLD`, and `UNLINKED_RETURN`.
    The default is null.
    """

    limit: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The number of [records](entity:InventoryCount) to return.
    """
