# This file was auto-generated by Fern from our API Definition.

import typing

BusinessAppointmentSettingsBookingLocationType = typing.Union[
    typing.Literal["BUSINESS_LOCATION", "CUSTOMER_LOCATION", "PHONE"], typing.Any
]
