# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .date_range import DateRangeParams
from ..types.scheduled_shift_workday_matcher import ScheduledShiftWorkdayMatcher
import typing


class ScheduledShiftWorkdayParams(typing_extensions.TypedDict):
    """
    A `ScheduledShift` search query filter parameter that sets a range of days that
    a `Shift` must start or end in before passing the filter condition.
    """

    date_range: typing_extensions.NotRequired[DateRangeParams]
    """
    Dates for fetching the scheduled shifts.
    """

    match_scheduled_shifts_by: typing_extensions.NotRequired[ScheduledShiftWorkdayMatcher]
    """
    The strategy on which the dates are applied.
    See [ScheduledShiftWorkdayMatcher](#type-scheduledshiftworkdaymatcher) for possible values
    """

    default_timezone: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Location-specific timezones convert workdays to datetime filters.
    Every location included in the query must have a timezone or this field
    must be provided as a fallback. Format: the IANA timezone database
    identifier for the relevant timezone.
    """
