# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogCustomAttributeDefinitionSelectionConfigCustomAttributeSelectionParams(typing_extensions.TypedDict):
    """
    A named selection for this `SELECTION`-type custom attribute definition.
    """

    uid: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Unique ID set by Square.
    """

    name: str
    """
    Selection name, unique within `allowed_selections`.
    """
