# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .tender_bank_account_details_status import TenderBankAccountDetailsStatus
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TenderBankAccountDetails(UncheckedBaseModel):
    """
    Represents the details of a tender with `type` `BANK_ACCOUNT`.

    See [BankAccountPaymentDetails](entity:BankAccountPaymentDetails)
    for more exposed details of a bank account payment.
    """

    status: typing.Optional[TenderBankAccountDetailsStatus] = pydantic.Field(default=None)
    """
    The bank account payment's current state.
    
    See [TenderBankAccountPaymentDetailsStatus](entity:TenderBankAccountDetailsStatus) for possible values.
    See [TenderBankAccountDetailsStatus](#type-tenderbankaccountdetailsstatus) for possible values
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
