# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class LoyaltyEventRedeemRewardParams(typing_extensions.TypedDict):
    """
    Provides metadata when the event `type` is `REDEEM_REWARD`.
    """

    loyalty_program_id: str
    """
    The ID of the [loyalty program](entity:LoyaltyProgram).
    """

    reward_id: typing_extensions.NotRequired[str]
    """
    The ID of the redeemed [loyalty reward](entity:LoyaltyReward).
    This field is returned only if the event source is `LOYALTY_API`.
    """

    order_id: typing_extensions.NotRequired[str]
    """
    The ID of the [order](entity:Order) that redeemed the reward.
    This field is returned only if the Orders API is used to process orders.
    """
