# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CustomerDetailsParams(typing_extensions.TypedDict):
    """
    Details about the customer making the payment.
    """

    customer_initiated: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates whether the customer initiated the payment.
    """

    seller_keyed_in: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates that the seller keyed in payment details on behalf of the customer.
    This is used to flag a payment as Mail Order / Telephone Order (MOTO).
    """
