# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SelectOptionParams(typing_extensions.TypedDict):
    reference_id: str
    """
    The reference id for the option.
    """

    title: str
    """
    The title text that displays in the select option button.
    """
