# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .customer import CustomerParams


class GetCustomerResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the `RetrieveCustomer` endpoint.

    Either `errors` or `customer` is present in a given response (never both).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    customer: typing_extensions.NotRequired[CustomerParams]
    """
    The requested customer.
    """
