# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CustomFieldParams(typing_extensions.TypedDict):
    """
    Describes a custom form field to add to the checkout page to collect more information from buyers during checkout.
    For more information,
    see [Specify checkout options](https://developer.squareup.com/docs/checkout-api/optional-checkout-configurations#specify-checkout-options-1).
    """

    title: str
    """
    The title of the custom field.
    """
