# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.v1order_history_entry_action import V1OrderHistoryEntryAction


class V1OrderHistoryEntryParams(typing_extensions.TypedDict):
    """
    V1OrderHistoryEntry
    """

    action: typing_extensions.NotRequired[V1OrderHistoryEntryAction]
    """
    The type of action performed on the order.
    See [V1OrderHistoryEntryAction](#type-v1orderhistoryentryaction) for possible values
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The time when the action was performed, in ISO 8601 format.
    """
