# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .dispute import DisputeParams


class ListDisputesResponseParams(typing_extensions.TypedDict):
    """
    Defines fields in a `ListDisputes` response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    disputes: typing_extensions.NotRequired[typing.Sequence[DisputeParams]]
    """
    The list of disputes.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in a subsequent request.
    If unset, this is the final response. For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
