# This file was auto-generated by Fern from our API Definition.

import typing

TenderCardDetailsEntryMethod = typing.Union[
    typing.Literal["SWIPED", "KEYED", "EMV", "ON_FILE", "CONTACTLESS"], typing.Any
]
