# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .loyalty_event_loyalty_account_filter import LoyaltyEventLoyaltyAccountFilterParams
from .loyalty_event_type_filter import LoyaltyEventTypeFilterParams
from .loyalty_event_date_time_filter import LoyaltyEventDateTimeFilterParams
from .loyalty_event_location_filter import LoyaltyEventLocationFilterParams
from .loyalty_event_order_filter import LoyaltyEventOrderFilterParams


class LoyaltyEventFilterParams(typing_extensions.TypedDict):
    """
    The filtering criteria. If the request specifies multiple filters,
    the endpoint uses a logical AND to evaluate them.
    """

    loyalty_account_filter: typing_extensions.NotRequired[LoyaltyEventLoyaltyAccountFilterParams]
    """
    Filter events by loyalty account.
    """

    type_filter: typing_extensions.NotRequired[LoyaltyEventTypeFilterParams]
    """
    Filter events by event type.
    """

    date_time_filter: typing_extensions.NotRequired[LoyaltyEventDateTimeFilterParams]
    """
    Filter events by date time range. 
    For each range, the start time is inclusive and the end time 
    is exclusive.
    """

    location_filter: typing_extensions.NotRequired[LoyaltyEventLocationFilterParams]
    """
    Filter events by location.
    """

    order_filter: typing_extensions.NotRequired[LoyaltyEventOrderFilterParams]
    """
    Filter events by the order associated with the event.
    """
