# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CardPaymentTimeline(UncheckedBaseModel):
    """
    The timeline for card payments.
    """

    authorized_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The timestamp when the payment was authorized, in RFC 3339 format.
    """

    captured_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The timestamp when the payment was captured, in RFC 3339 format.
    """

    voided_at: typing.Optional[str] = pydantic.Field(default=None)
    """
    The timestamp when the payment was voided, in RFC 3339 format.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
