# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .time_range import TimeRangeParams


class LoyaltyEventDateTimeFilterParams(typing_extensions.TypedDict):
    """
    Filter events by date time range.
    """

    created_at: TimeRangeParams
    """
    The `created_at` date time range used to filter the result.
    """
