# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class BatchDeleteCatalogObjectsResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    deleted_object_ids: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The IDs of all CatalogObjects deleted by this request.
    """

    deleted_at: typing_extensions.NotRequired[str]
    """
    The database [timestamp](https://developer.squareup.com/docs/build-basics/working-with-dates) of this deletion in RFC 3339 format, e.g., "2016-09-04T23:59:33.123Z".
    """
