# This file was auto-generated by Fern from our API Definition.

import typing

CatalogCustomAttributeDefinitionType = typing.Union[
    typing.Literal["STRING", "BOOLEAN", "NUMBER", "SELECTION"], typing.Any
]
