# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .event_type_metadata import EventTypeMetadataParams


class ListEventTypesResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the [ListEventTypes](api-endpoint:Events-ListEventTypes) endpoint.

    Note: if there are errors processing the request, the event types field will not be
    present.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information on errors encountered during the request.
    """

    event_types: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The list of event types.
    """

    metadata: typing_extensions.NotRequired[typing.Sequence[EventTypeMetadataParams]]
    """
    Contains the metadata of an event type. For more information, see [EventTypeMetadata](entity:EventTypeMetadata).
    """
