# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .create_vendor_response import CreateVendorResponseParams


class BatchCreateVendorsResponseParams(typing_extensions.TypedDict):
    """
    Represents an output from a call to [BulkCreateVendors](api-endpoint:Vendors-BulkCreateVendors).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    responses: typing_extensions.NotRequired[typing.Dict[str, CreateVendorResponseParams]]
    """
    A set of [CreateVendorResponse](entity:CreateVendorResponse) objects encapsulating successfully created [Vendor](entity:Vendor)
    objects or error responses for failed attempts. The set is represented by 
    a collection of idempotency-key/`Vendor`-object or idempotency-key/error-object pairs. The idempotency keys correspond to those specified
    in the input.
    """
