# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .business_hours_period import BusinessHoursPeriodParams


class BusinessHoursParams(typing_extensions.TypedDict):
    """
    The hours of operation for a location.
    """

    periods: typing_extensions.NotRequired[typing.Optional[typing.Sequence[BusinessHoursPeriodParams]]]
    """
    The list of time periods during which the business is open. There can be at most 10 periods per day.
    """
