# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .dispute import DisputeParams


class AcceptDisputeResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields in an `AcceptDispute` response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    dispute: typing_extensions.NotRequired[DisputeParams]
    """
    Details about the accepted dispute.
    """
