# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .measurement_unit import MeasurementUnitParams
import typing


class StandardUnitDescriptionParams(typing_extensions.TypedDict):
    """
    Contains the name and abbreviation for standard measurement unit.
    """

    unit: typing_extensions.NotRequired[MeasurementUnitParams]
    """
    Identifies the measurement unit being described.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    UI display name of the measurement unit. For example, 'Pound'.
    """

    abbreviation: typing_extensions.NotRequired[typing.Optional[str]]
    """
    UI display abbreviation for the measurement unit. For example, 'lb'.
    """
