# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_promotion import LoyaltyPromotionParams


class GetLoyaltyPromotionResponseParams(typing_extensions.TypedDict):
    """
    Represents a [RetrieveLoyaltyPromotionPromotions](api-endpoint:Loyalty-RetrieveLoyaltyPromotion) response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    loyalty_promotion: typing_extensions.NotRequired[LoyaltyPromotionParams]
    """
    The retrieved loyalty promotion.
    """
