# This file was auto-generated by Fern from our API Definition.

import typing

CatalogItemFoodAndBeverageDetailsIngredientStandardIngredient = typing.Union[
    typing.Literal[
        "CELERY",
        "CRUSTACEANS",
        "EGGS",
        "FISH",
        "GLUTEN",
        "LUPIN",
        "MILK",
        "MOLLUSCS",
        "MUSTARD",
        "PEANUTS",
        "SESAME",
        "SOY",
        "SULPHITES",
        "TREE_NUTS",
    ],
    typing.Any,
]
