# This file was auto-generated by Fern from our API Definition.

import enum


class SquareEnvironment(enum.Enum):
    PRODUCTION = "https://connect.squareup.com"
    SANDBOX = "https://connect.squareupsandbox.com"
