# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .shift import ShiftParams
import typing
from .error import ErrorParams


class GetShiftResponseParams(typing_extensions.TypedDict):
    """
    A response to a request to get a `Shift`. The response contains
    the requested `Shift` object and might contain a set of `Error` objects if
    the request resulted in errors.
    """

    shift: typing_extensions.NotRequired[ShiftParams]
    """
    The requested `Shift`.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
