# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .site import SiteParams


class ListSitesResponseParams(typing_extensions.TypedDict):
    """
    Represents a `ListSites` response. The response can include either `sites` or `errors`.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    sites: typing_extensions.NotRequired[typing.Sequence[SiteParams]]
    """
    The sites that belong to the seller.
    """
