# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .webhook_subscription import WebhookSubscriptionParams


class CreateWebhookSubscriptionResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the [CreateWebhookSubscription](api-endpoint:WebhookSubscriptions-CreateWebhookSubscription) endpoint.

    Note: if there are errors processing the request, the [Subscription](entity:WebhookSubscription) will not be
    present.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information on errors encountered during the request.
    """

    subscription: typing_extensions.NotRequired[WebhookSubscriptionParams]
    """
    The new [Subscription](entity:WebhookSubscription).
    """
