# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_promotion import LoyaltyPromotionParams


class ListLoyaltyPromotionsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [ListLoyaltyPromotions](api-endpoint:Loyalty-ListLoyaltyPromotions) response.
    One of `loyalty_promotions`, an empty object, or `errors` is present in the response.
    If additional results are available, the `cursor` field is also present along with `loyalty_promotions`.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    loyalty_promotions: typing_extensions.NotRequired[typing.Sequence[LoyaltyPromotionParams]]
    """
    The retrieved loyalty promotions.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The cursor to use in your next call to this endpoint to retrieve the next page of results
    for your original request. This field is present only if the request succeeded and additional
    results are available. For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
