# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .search_availability_filter import SearchAvailabilityFilterParams


class SearchAvailabilityQueryParams(typing_extensions.TypedDict):
    """
    The query used to search for buyer-accessible availabilities of bookings.
    """

    filter: SearchAvailabilityFilterParams
    """
    The query filter to search for buyer-accessible availabilities of existing bookings.
    """
