# This file was auto-generated by Fern from our API Definition.

import typing

CatalogCustomAttributeDefinitionSellerVisibility = typing.Union[
    typing.Literal["SELLER_VISIBILITY_HIDDEN", "SELLER_VISIBILITY_READ_WRITE_VALUES"], typing.Any
]
