# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .time_range import TimeRangeParams


class TerminalCheckoutQueryFilterParams(typing_extensions.TypedDict):
    device_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The `TerminalCheckout` objects associated with a specific device. If no device is specified, then all
    `TerminalCheckout` objects for the merchant are displayed.
    """

    created_at: typing_extensions.NotRequired[TimeRangeParams]
    """
    The time range for the beginning of the reporting period, which is inclusive.
    Default value: The current time minus one day.
    Note that `TerminalCheckout`s are available for 30 days after creation.
    """

    status: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Filtered results with the desired status of the `TerminalCheckout`.
    Options: `PENDING`, `IN_PROGRESS`, `CANCEL_REQUESTED`, `CANCELED`, `COMPLETED`
    """
