# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .checkout_merchant_settings_payment_methods import CheckoutMerchantSettingsPaymentMethodsParams


class CheckoutMerchantSettingsParams(typing_extensions.TypedDict):
    payment_methods: typing_extensions.NotRequired[CheckoutMerchantSettingsPaymentMethodsParams]
    """
    The set of payment methods accepted for the merchant's account.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the settings were last updated, in RFC 3339 format.
    Examples for January 25th, 2020 6:25:34pm Pacific Standard Time:
    UTC: 2020-01-26T02:25:34Z
    Pacific Standard Time with UTC offset: 2020-01-25T18:25:34-08:00
    """
