# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .location import LocationParams


class ListLocationsResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of a request
    to the [ListLocations](api-endpoint:Locations-ListLocations) endpoint.

    Either `errors` or `locations` is present in a given response (never both).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    locations: typing_extensions.NotRequired[typing.Sequence[LocationParams]]
    """
    The business locations.
    """
