# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class DeviceComponentDetailsEthernetDetailsParams(typing_extensions.TypedDict):
    active: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    A boolean to represent whether the Ethernet interface is currently active.
    """

    ip_address_v4: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The string representation of the device’s IPv4 address.
    """
