# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .subscription import SubscriptionParams


class SearchSubscriptionsResponseParams(typing_extensions.TypedDict):
    """
    Defines output parameters in a response from the
    [SearchSubscriptions](api-endpoint:Subscriptions-SearchSubscriptions) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered during the request.
    """

    subscriptions: typing_extensions.NotRequired[typing.Sequence[SubscriptionParams]]
    """
    The subscriptions matching the specified query expressions.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    When the total number of resulting subscription exceeds the limit of a paged response, 
    the response includes a cursor for you to use in a subsequent request to fetch the next set of results.
    If the cursor is unset, the response contains the last page of the results.
    
    For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
