# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .order import OrderParams


class CreateOrderRequestParams(typing_extensions.TypedDict):
    order: typing_extensions.NotRequired[OrderParams]
    """
    The order to create. If this field is set, the only other top-level field that can be
    set is the `idempotency_key`.
    """

    idempotency_key: typing_extensions.NotRequired[str]
    """
    A value you specify that uniquely identifies this
    order among orders you have created.
    
    If you are unsure whether a particular order was created successfully,
    you can try it again with the same idempotency key without
    worrying about creating duplicate orders.
    
    For more information, see [Idempotency](https://developer.squareup.com/docs/build-basics/common-api-patterns/idempotency).
    """
