# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .invoice_attachment import InvoiceAttachmentParams
import typing
from .error import ErrorParams


class CreateInvoiceAttachmentResponseParams(typing_extensions.TypedDict):
    """
    Represents a [CreateInvoiceAttachment](api-endpoint:Invoices-CreateInvoiceAttachment) response.
    """

    attachment: typing_extensions.NotRequired[InvoiceAttachmentParams]
    """
    Metadata about the attachment that was added to the invoice.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """
