# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .order_line_item_pricing_blocklists_blocked_discount import OrderLineItemPricingBlocklistsBlockedDiscountParams
from .order_line_item_pricing_blocklists_blocked_tax import OrderLineItemPricingBlocklistsBlockedTaxParams


class OrderLineItemPricingBlocklistsParams(typing_extensions.TypedDict):
    """
    Describes pricing adjustments that are blocked from automatic
    application to a line item. For more information, see
    [Apply Taxes and Discounts](https://developer.squareup.com/docs/orders-api/apply-taxes-and-discounts).
    """

    blocked_discounts: typing_extensions.NotRequired[
        typing.Optional[typing.Sequence[OrderLineItemPricingBlocklistsBlockedDiscountParams]]
    ]
    """
    A list of discounts blocked from applying to the line item.
    Discounts can be blocked by the `discount_uid` (for ad hoc discounts) or
    the `discount_catalog_object_id` (for catalog discounts).
    """

    blocked_taxes: typing_extensions.NotRequired[
        typing.Optional[typing.Sequence[OrderLineItemPricingBlocklistsBlockedTaxParams]]
    ]
    """
    A list of taxes blocked from applying to the line item.
    Taxes can be blocked by the `tax_uid` (for ad hoc taxes) or
    the `tax_catalog_object_id` (for catalog taxes).
    """
