# This file was auto-generated by Fern from our API Definition.

import typing

CustomAttributeDefinitionVisibility = typing.Union[
    typing.Literal["VISIBILITY_HIDDEN", "VISIBILITY_READ_ONLY", "VISIBILITY_READ_WRITE_VALUES"], typing.Any
]
