# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .location import LocationParams


class GetLocationResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that the [RetrieveLocation](api-endpoint:Locations-RetrieveLocation)
    endpoint returns in a response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    location: typing_extensions.NotRequired[LocationParams]
    """
    The requested location.
    """
