# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .dispute_evidence_file import DisputeEvidenceFileParams
from ..types.dispute_evidence_type import DisputeEvidenceType


class DisputeEvidenceParams(typing_extensions.TypedDict):
    evidence_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The Square-generated ID of the evidence.
    """

    id: typing_extensions.NotRequired[str]
    """
    The Square-generated ID of the evidence.
    """

    dispute_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the dispute the evidence is associated with.
    """

    evidence_file: typing_extensions.NotRequired[DisputeEvidenceFileParams]
    """
    Image, PDF, TXT
    """

    evidence_text: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Raw text
    """

    uploaded_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The time when the evidence was uploaded, in RFC 3339 format.
    """

    evidence_type: typing_extensions.NotRequired[DisputeEvidenceType]
    """
    The type of the evidence.
    See [DisputeEvidenceType](#type-disputeevidencetype) for possible values
    """
