# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams


class QuickPayParams(typing_extensions.TypedDict):
    """
    Describes an ad hoc item and price to generate a quick pay checkout link.
    For more information,
    see [Quick Pay Checkout](https://developer.squareup.com/docs/checkout-api/quick-pay-checkout).
    """

    name: str
    """
    The ad hoc item name. In the resulting `Order`, this name appears as the line item name.
    """

    price_money: MoneyParams
    """
    The price of the item.
    """

    location_id: str
    """
    The ID of the business location the checkout is associated with.
    """
