# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .team_member_booking_profile import TeamMemberBookingProfileParams
from .error import ErrorParams


class ListTeamMemberBookingProfilesResponseParams(typing_extensions.TypedDict):
    team_member_booking_profiles: typing_extensions.NotRequired[typing.Sequence[TeamMemberBookingProfileParams]]
    """
    The list of team member booking profiles. The results are returned in the ascending order of the time
    when the team member booking profiles were last updated. Multiple booking profiles updated at the same time
    are further sorted in the ascending order of their IDs.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in the subsequent request to get the next page of the results. Stop retrieving the next page of the results when the cursor is not set.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred during the request.
    """
