# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.tender_bank_account_details_status import TenderBankAccountDetailsStatus


class TenderBankAccountDetailsParams(typing_extensions.TypedDict):
    """
    Represents the details of a tender with `type` `BANK_ACCOUNT`.

    See [BankAccountPaymentDetails](entity:BankAccountPaymentDetails)
    for more exposed details of a bank account payment.
    """

    status: typing_extensions.NotRequired[TenderBankAccountDetailsStatus]
    """
    The bank account payment's current state.
    
    See [TenderBankAccountPaymentDetailsStatus](entity:TenderBankAccountDetailsStatus) for possible values.
    See [TenderBankAccountDetailsStatus](#type-tenderbankaccountdetailsstatus) for possible values
    """
