# This file was auto-generated by Fern from our API Definition.

import typing

V1TenderCardBrand = typing.Union[
    typing.Literal[
        "OTHER_BRAND",
        "VISA",
        "MASTER_CARD",
        "AMERICAN_EXPRESS",
        "DISCOVER",
        "DISCOVER_DINERS",
        "JCB",
        "CHINA_UNIONPAY",
        "SQUARE_GIFT_CARD",
    ],
    typing.Any,
]
