# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .payout import PayoutParams
import typing
from .error import ErrorParams


class GetPayoutResponseParams(typing_extensions.TypedDict):
    payout: typing_extensions.NotRequired[PayoutParams]
    """
    The requested payout.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """
