# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams
import typing_extensions
import typing


class GiftCardActivityUnlinkedActivityRefundParams(typing_extensions.TypedDict):
    """
    Represents details about an `UNLINKED_ACTIVITY_REFUND` [gift card activity type](entity:GiftCardActivityType).
    """

    amount_money: MoneyParams
    """
    The amount added to the gift card for the refund. This value is a positive integer.
    """

    reference_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A client-specified ID that associates the gift card activity with an entity in another system.
    """

    payment_id: typing_extensions.NotRequired[str]
    """
    The ID of the refunded payment. This field is not used starting in Square version 2022-06-16.
    """
