# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .terminal_action_query_filter import TerminalActionQueryFilterParams
from .terminal_action_query_sort import TerminalActionQuerySortParams


class TerminalActionQueryParams(typing_extensions.TypedDict):
    filter: typing_extensions.NotRequired[TerminalActionQueryFilterParams]
    """
    Options for filtering returned `TerminalAction`s
    """

    sort: typing_extensions.NotRequired[TerminalActionQuerySortParams]
    """
    Option for sorting returned `TerminalAction` objects.
    """
