# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from ..types.fulfillment_type import FulfillmentType
from ..types.fulfillment_state import FulfillmentState


class SearchOrdersFulfillmentFilterParams(typing_extensions.TypedDict):
    """
    Filter based on [order fulfillment](entity:Fulfillment) information.
    """

    fulfillment_types: typing_extensions.NotRequired[typing.Optional[typing.Sequence[FulfillmentType]]]
    """
    A list of [fulfillment types](entity:FulfillmentType) to filter
    for. The list returns orders if any of its fulfillments match any of the fulfillment types
    listed in this field.
    See [FulfillmentType](#type-fulfillmenttype) for possible values
    """

    fulfillment_states: typing_extensions.NotRequired[typing.Optional[typing.Sequence[FulfillmentState]]]
    """
    A list of [fulfillment states](entity:FulfillmentState) to filter
    for. The list returns orders if any of its fulfillments match any of the
    fulfillment states listed in this field.
    See [FulfillmentState](#type-fulfillmentstate) for possible values
    """
