# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .team_member import TeamMemberParams
from .error import ErrorParams


class SearchTeamMembersResponseParams(typing_extensions.TypedDict):
    """
    Represents a response from a search request containing a filtered list of `TeamMember` objects.
    """

    team_members: typing_extensions.NotRequired[typing.Sequence[TeamMemberParams]]
    """
    The filtered list of `TeamMember` objects.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The opaque cursor for fetching the next page. For more information, see
    [pagination](https://developer.squareup.com/docs/working-with-apis/pagination).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    The errors that occurred during the request.
    """
