# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CatalogQueryPrefixParams(typing_extensions.TypedDict):
    """
    The query filter to return the search result whose named attribute values are prefixed by the specified attribute value.
    """

    attribute_name: str
    """
    The name of the attribute to be searched.
    """

    attribute_prefix: str
    """
    The desired prefix of the search attribute value.
    """
