# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .dispute_evidence_type import DisputeEvidenceType
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class CreateDisputeEvidenceFileRequest(UncheckedBaseModel):
    """
    Defines the parameters for a `CreateDisputeEvidenceFile` request.
    """

    idempotency_key: str = pydantic.Field()
    """
    A unique key identifying the request. For more information, see [Idempotency](https://developer.squareup.com/docs/working-with-apis/idempotency).
    """

    evidence_type: typing.Optional[DisputeEvidenceType] = pydantic.Field(default=None)
    """
    The type of evidence you are uploading.
    See [DisputeEvidenceType](#type-disputeevidencetype) for possible values
    """

    content_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The MIME type of the uploaded file.
    The type can be image/heic, image/heif, image/jpeg, application/pdf, image/png, or image/tiff.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
