# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class CustomerSegmentParams(typing_extensions.TypedDict):
    """
    Represents a group of customer profiles that match one or more predefined filter criteria.

    Segments (also known as Smart Groups) are defined and created within the Customer Directory in the
    Square Seller Dashboard or Point of Sale.
    """

    id: typing_extensions.NotRequired[str]
    """
    A unique Square-generated ID for the segment.
    """

    name: str
    """
    The name of the segment.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the segment was created, in RFC 3339 format.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp when the segment was last updated, in RFC 3339 format.
    """
