# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class PhaseInputParams(typing_extensions.TypedDict):
    """
    Represents the arguments used to construct a new phase.
    """

    ordinal: int
    """
    index of phase in total subscription plan
    """

    order_template_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    id of order to be used in billing
    """
