# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CategoryPathToRootNodeParams(typing_extensions.TypedDict):
    """
    A node in the path from a retrieved category to its root node.
    """

    category_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The category's ID.
    """

    category_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The category's name.
    """
