# This file was auto-generated by Fern from our API Definition.

import typing

DestinationType = typing.Union[
    typing.Literal["BANK_ACCOUNT", "CARD", "SQUARE_BALANCE", "SQUARE_STORED_BALANCE"], typing.Any
]
