# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class CalculateLoyaltyPointsResponseParams(typing_extensions.TypedDict):
    """
    Represents a [CalculateLoyaltyPoints](api-endpoint:Loyalty-CalculateLoyaltyPoints) response.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    points: typing_extensions.NotRequired[int]
    """
    The number of points that the buyer can earn from the base loyalty program.
    """

    promotion_points: typing_extensions.NotRequired[int]
    """
    The number of points that the buyer can earn from a loyalty promotion. To be eligible
    to earn promotion points, the purchase must first qualify for program points. When `order_id`
    is not provided in the request, this value is always 0.
    """
