# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .snippet import SnippetParams


class GetSnippetResponseParams(typing_extensions.TypedDict):
    """
    Represents a `RetrieveSnippet` response. The response can include either `snippet` or `errors`.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    snippet: typing_extensions.NotRequired[SnippetParams]
    """
    The retrieved snippet.
    """
