# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.loyalty_reward_status import LoyaltyRewardStatus


class SearchLoyaltyRewardsRequestLoyaltyRewardQueryParams(typing_extensions.TypedDict):
    """
    The set of search requirements.
    """

    loyalty_account_id: str
    """
    The ID of the [loyalty account](entity:LoyaltyAccount) to which the loyalty reward belongs.
    """

    status: typing_extensions.NotRequired[LoyaltyRewardStatus]
    """
    The status of the loyalty reward.
    See [LoyaltyRewardStatus](#type-loyaltyrewardstatus) for possible values
    """
