# This file was auto-generated by Fern from our API Definition.

import typing

ArchivedState = typing.Union[
    typing.Literal["ARCHIVED_STATE_NOT_ARCHIVED", "ARCHIVED_STATE_ARCHIVED", "ARCHIVED_STATE_ALL"], typing.Any
]
