# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.search_vendors_request_sort_field import SearchVendorsRequestSortField
from ..types.sort_order import SortOrder


class SearchVendorsRequestSortParams(typing_extensions.TypedDict):
    """
    Defines a sorter used to sort results from [SearchVendors](api-endpoint:Vendors-SearchVendors).
    """

    field: typing_extensions.NotRequired[SearchVendorsRequestSortField]
    """
    Specifies the sort key to sort the returned vendors.
    See [Field](#type-field) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    Specifies the sort order for the returned vendors.
    See [SortOrder](#type-sortorder) for possible values
    """
