# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.dispute_evidence_type import DisputeEvidenceType


class CreateDisputeEvidenceFileRequestParams(typing_extensions.TypedDict):
    """
    Defines the parameters for a `CreateDisputeEvidenceFile` request.
    """

    idempotency_key: str
    """
    A unique key identifying the request. For more information, see [Idempotency](https://developer.squareup.com/docs/working-with-apis/idempotency).
    """

    evidence_type: typing_extensions.NotRequired[DisputeEvidenceType]
    """
    The type of evidence you are uploading.
    See [DisputeEvidenceType](#type-disputeevidencetype) for possible values
    """

    content_type: typing_extensions.NotRequired[str]
    """
    The MIME type of the uploaded file.
    The type can be image/heic, image/heif, image/jpeg, application/pdf, image/png, or image/tiff.
    """
