# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.scheduled_shift_sort_field import ScheduledShiftSortField
from ..types.sort_order import SortOrder


class ScheduledShiftSortParams(typing_extensions.TypedDict):
    """
    Defines sort criteria for a [SearchScheduledShifts](api-endpoint:Labor-SearchScheduledShifts)
    request.
    """

    field: typing_extensions.NotRequired[ScheduledShiftSortField]
    """
    The field to sort on. The default value is `START_AT`.
    See [ScheduledShiftSortField](#type-scheduledshiftsortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    The order in which results are returned. The default value is `ASC`.
    See [SortOrder](#type-sortorder) for possible values
    """
