# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class LocationBookingProfile(UncheckedBaseModel):
    """
    The booking profile of a seller's location, including the location's ID and whether the location is enabled for online booking.
    """

    location_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    The ID of the [location](entity:Location).
    """

    booking_site_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Url for the online booking site for this location.
    """

    online_booking_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Indicates whether the location is enabled for online booking.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
