# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CustomerPreferencesParams(typing_extensions.TypedDict):
    """
    Represents communication preferences for the customer profile.
    """

    email_unsubscribed: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates whether the customer has unsubscribed from marketing campaign emails. A value of `true` means that the customer chose to opt out of email marketing from the current Square seller or from all Square sellers. This value is read-only from the Customers API.
    """
