# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CheckoutLocationSettingsCouponsParams(typing_extensions.TypedDict):
    enabled: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates whether coupons are enabled for this location.
    """
