# This file was auto-generated by Fern from our API Definition.

import typing

CatalogItemFoodAndBeverageDetailsDietaryPreferenceType = typing.Union[typing.Literal["STANDARD", "CUSTOM"], typing.Any]
