# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.catalog_quick_amounts_settings_option import CatalogQuickAmountsSettingsOption
import typing_extensions
import typing
from .catalog_quick_amount import CatalogQuickAmountParams


class CatalogQuickAmountsSettingsParams(typing_extensions.TypedDict):
    """
    A parent Catalog Object model represents a set of Quick Amounts and the settings control the amounts.
    """

    option: CatalogQuickAmountsSettingsOption
    """
    Represents the option seller currently uses on Quick Amounts.
    See [CatalogQuickAmountsSettingsOption](#type-catalogquickamountssettingsoption) for possible values
    """

    eligible_for_auto_amounts: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Represents location's eligibility for auto amounts
    The boolean should be consistent with whether there are AUTO amounts in the `amounts`.
    """

    amounts: typing_extensions.NotRequired[typing.Optional[typing.Sequence[CatalogQuickAmountParams]]]
    """
    Represents a set of Quick Amounts at this location.
    """
