# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .time_range import TimeRange
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class TerminalRefundQueryFilter(UncheckedBaseModel):
    device_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    `TerminalRefund` objects associated with a specific device. If no device is specified, then all
    `TerminalRefund` objects for the signed-in account are displayed.
    """

    created_at: typing.Optional[TimeRange] = pydantic.Field(default=None)
    """
    The timestamp for the beginning of the reporting period, in RFC 3339 format. Inclusive.
    Default value: The current time minus one day.
    Note that `TerminalRefund`s are available for 30 days after creation.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filtered results with the desired status of the `TerminalRefund`.
    Options: `PENDING`, `IN_PROGRESS`, `CANCEL_REQUESTED`, `CANCELED`, or `COMPLETED`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
