# This file was auto-generated by Fern from our API Definition.

import typing

SubscriptionStatus = typing.Union[typing.Literal["PENDING", "ACTIVE", "CANCELED", "DEACTIVATED", "PAUSED"], typing.Any]
