# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .date_range import DateRangeParams
from ..types.timecard_workday_matcher import TimecardWorkdayMatcher
import typing


class TimecardWorkdayParams(typing_extensions.TypedDict):
    """
    A `Timecard` search query filter parameter that sets a range of days that
    a `Timecard` must start or end in before passing the filter condition.
    """

    date_range: typing_extensions.NotRequired[DateRangeParams]
    """
    Dates for fetching the timecards.
    """

    match_timecards_by: typing_extensions.NotRequired[TimecardWorkdayMatcher]
    """
    The strategy on which the dates are applied.
    See [TimecardWorkdayMatcher](#type-timecardworkdaymatcher) for possible values
    """

    default_timezone: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Location-specific timezones convert workdays to datetime filters.
    Every location included in the query must have a timezone or this field
    must be provided as a fallback. Format: the IANA timezone database
    identifier for the relevant timezone.
    """
