# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class AppointmentSegmentParams(typing_extensions.TypedDict):
    """
    Defines an appointment segment of a booking.
    """

    duration_minutes: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The time span in minutes of an appointment segment.
    """

    service_variation_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the [CatalogItemVariation](entity:CatalogItemVariation) object representing the service booked in this segment.
    """

    team_member_id: str
    """
    The ID of the [TeamMember](entity:TeamMember) object representing the team member booked in this segment.
    """

    service_variation_version: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The current version of the item variation representing the service booked in this segment.
    """

    intermission_minutes: typing_extensions.NotRequired[int]
    """
    Time between the end of this segment and the beginning of the subsequent segment.
    """

    any_team_member: typing_extensions.NotRequired[bool]
    """
    Whether the customer accepts any team member, instead of a specific one, to serve this segment.
    """

    resource_ids: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    The IDs of the seller-accessible resources used for this appointment segment.
    """
