# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementUnitArea = typing.Union[
    typing.Literal[
        "IMPERIAL_ACRE",
        "IMPERIAL_SQUARE_INCH",
        "IMPERIAL_SQUARE_FOOT",
        "IMPERIAL_SQUARE_YARD",
        "IMPERIAL_SQUARE_MILE",
        "METRIC_SQUARE_CENTIMETER",
        "METRIC_SQUARE_METER",
        "METRIC_SQUARE_KILOMETER",
    ],
    typing.Any,
]
