# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .search_orders_filter import SearchOrdersFilterParams
from .search_orders_sort import SearchOrdersSortParams


class SearchOrdersQueryParams(typing_extensions.TypedDict):
    """
    Contains query criteria for the search.
    """

    filter: typing_extensions.NotRequired[SearchOrdersFilterParams]
    """
    Criteria to filter results by.
    """

    sort: typing_extensions.NotRequired[SearchOrdersSortParams]
    """
    Criteria to sort results by.
    """
