# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class CreateMobileAuthorizationCodeResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the `CreateMobileAuthorizationCode` endpoint.
    """

    authorization_code: typing_extensions.NotRequired[str]
    """
    The generated authorization code that connects a mobile application instance
    to a Square account.
    """

    expires_at: typing_extensions.NotRequired[str]
    """
    The timestamp when `authorization_code` expires, in
    [RFC 3339](https://tools.ietf.org/html/rfc3339) format (for example, "2016-09-04T23:59:33.123Z").
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
