# This file was auto-generated by Fern from our API Definition.

import typing

CatalogCategoryType = typing.Union[typing.Literal["REGULAR_CATEGORY", "MENU_CATEGORY", "KITCHEN_CATEGORY"], typing.Any]
