# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing
from .select_option import SelectOptionParams
import typing_extensions


class SelectOptionsParams(typing_extensions.TypedDict):
    title: str
    """
    The title text to display in the select flow on the Terminal.
    """

    body: str
    """
    The body text to display in the select flow on the Terminal.
    """

    options: typing.Sequence[SelectOptionParams]
    """
    Represents the buttons/options that should be displayed in the select flow on the Terminal.
    """

    selected_option: typing_extensions.NotRequired[SelectOptionParams]
    """
    The buyer’s selected option.
    """
