# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing
from .catalog_object_image import CatalogObjectImageParams
from .catalog_object_category import CatalogObjectCategoryParams
from .catalog_object_item_variation import CatalogObjectItemVariationParams
from .catalog_object_tax import CatalogObjectTaxParams
from .catalog_object_discount import CatalogObjectDiscountParams
from .catalog_object_modifier import CatalogObjectModifierParams
from .catalog_object_pricing_rule import CatalogObjectPricingRuleParams
from .catalog_object_product_set import CatalogObjectProductSetParams
from .catalog_object_time_period import CatalogObjectTimePeriodParams
from .catalog_object_measurement_unit import CatalogObjectMeasurementUnitParams
from .catalog_object_subscription_plan_variation import CatalogObjectSubscriptionPlanVariationParams
from .catalog_object_item_option_value import CatalogObjectItemOptionValueParams
from .catalog_object_custom_attribute_definition import CatalogObjectCustomAttributeDefinitionParams
from .catalog_object_quick_amounts_settings import CatalogObjectQuickAmountsSettingsParams
from .catalog_object_availability_period import CatalogObjectAvailabilityPeriodParams
import typing

if typing.TYPE_CHECKING:
    from .catalog_object_item import CatalogObjectItemParams
    from .catalog_object_modifier_list import CatalogObjectModifierListParams
    from .catalog_object_item_option import CatalogObjectItemOptionParams
    from .catalog_object_subscription_plan import CatalogObjectSubscriptionPlanParams
CatalogObjectParams = typing.Union[
    "CatalogObjectItemParams",
    CatalogObjectImageParams,
    CatalogObjectCategoryParams,
    CatalogObjectItemVariationParams,
    CatalogObjectTaxParams,
    CatalogObjectDiscountParams,
    "CatalogObjectModifierListParams",
    CatalogObjectModifierParams,
    CatalogObjectPricingRuleParams,
    CatalogObjectProductSetParams,
    CatalogObjectTimePeriodParams,
    CatalogObjectMeasurementUnitParams,
    CatalogObjectSubscriptionPlanVariationParams,
    "CatalogObjectItemOptionParams",
    CatalogObjectItemOptionValueParams,
    CatalogObjectCustomAttributeDefinitionParams,
    CatalogObjectQuickAmountsSettingsParams,
    "CatalogObjectSubscriptionPlanParams",
    CatalogObjectAvailabilityPeriodParams,
]
