# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .dispute_evidence import DisputeEvidenceParams
from .error import ErrorParams


class ListDisputeEvidenceResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields in a `ListDisputeEvidence` response.
    """

    evidence: typing_extensions.NotRequired[typing.Sequence[DisputeEvidenceParams]]
    """
    The list of evidence previously uploaded to the specified dispute.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in a subsequent request.
    If unset, this is the final response. For more information, see [Pagination](https://developer.squareup.com/docs/build-basics/common-api-patterns/pagination).
    """
