# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .money import MoneyParams
from .modifier_location_overrides import ModifierLocationOverridesParams


class CatalogModifierParams(typing_extensions.TypedDict):
    """
    A modifier that can be applied to items at the time of sale. For example, a cheese modifier for a burger, or a flavor modifier for a serving of ice cream.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The modifier name.  This is a searchable attribute for use in applicable query filters, and its value length is of Unicode code points.
    """

    price_money: typing_extensions.NotRequired[MoneyParams]
    """
    The modifier price.
    """

    on_by_default: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    When `true`, this modifier is selected by default when displaying the modifier list.
    This setting can be overridden at the item level using `CatalogModifierListInfo.modifier_overrides`.
    """

    ordinal: typing_extensions.NotRequired[typing.Optional[int]]
    """
    Determines where this `CatalogModifier` appears in the `CatalogModifierList`.
    """

    modifier_list_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the `CatalogModifierList` associated with this modifier.
    """

    location_overrides: typing_extensions.NotRequired[typing.Optional[typing.Sequence[ModifierLocationOverridesParams]]]
    """
    Location-specific price overrides.
    """

    image_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the image associated with this `CatalogModifier` instance.
    Currently this image is not displayed by Square, but is free to be displayed in 3rd party applications.
    """

    hidden_online: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    When `true`, this modifier is hidden from online ordering channels. This setting can be overridden at the item level using `CatalogModifierListInfo.modifier_overrides`.
    """
