# This file was auto-generated by Fern from our API Definition.

import typing

CatalogItemProductType = typing.Union[
    typing.Literal[
        "REGULAR",
        "GIFT_CARD",
        "APPOINTMENTS_SERVICE",
        "FOOD_AND_BEV",
        "EVENT",
        "DIGITAL",
        "DONATION",
        "LEGACY_SQUARE_ONLINE_SERVICE",
        "LEGACY_SQUARE_ONLINE_MEMBERSHIP",
    ],
    typing.Any,
]
