# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .select_option import SelectOption
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SelectOptions(UncheckedBaseModel):
    title: str = pydantic.Field()
    """
    The title text to display in the select flow on the Terminal.
    """

    body: str = pydantic.Field()
    """
    The body text to display in the select flow on the Terminal.
    """

    options: typing.List[SelectOption] = pydantic.Field()
    """
    Represents the buttons/options that should be displayed in the select flow on the Terminal.
    """

    selected_option: typing.Optional[SelectOption] = pydantic.Field(default=None)
    """
    The buyer’s selected option.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
