# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .event_data import EventDataParams


class EventParams(typing_extensions.TypedDict):
    merchant_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the target merchant associated with the event.
    """

    location_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The ID of the target location associated with the event.
    """

    type: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The type of event this represents.
    """

    event_id: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A unique ID for the event.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    Timestamp of when the event was created, in RFC 3339 format.
    """

    data: typing_extensions.NotRequired[EventDataParams]
    """
    The data associated with the event.
    """
