# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LoyaltyEventOtherParams(typing_extensions.TypedDict):
    """
    Provides metadata when the event `type` is `OTHER`.
    """

    loyalty_program_id: str
    """
    The Square-assigned ID of the [loyalty program](entity:LoyaltyProgram).
    """

    points: int
    """
    The number of points added or removed.
    """
