# This file was auto-generated by Fern from our API Definition.

import typing

DisputeReason = typing.Union[
    typing.Literal[
        "AMOUNT_DIFFERS",
        "CANCELLED",
        "DUPLICATE",
        "NO_KNOWLEDGE",
        "NOT_AS_DESCRIBED",
        "NOT_RECEIVED",
        "PAID_BY_OTHER_MEANS",
        "CUSTOMER_REQUESTS_CREDIT",
        "EMV_LIABILITY_SHIFT",
    ],
    typing.Any,
]
