# This file was auto-generated by Fern from our API Definition.

import typing

GiftCardActivityAdjustDecrementReason = typing.Union[
    typing.Literal["SUSPICIOUS_ACTIVITY", "BALANCE_ACCIDENTALLY_INCREASED", "SUPPORT_ISSUE", "PURCHASE_WAS_REFUNDED"],
    typing.Any,
]
