# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
from .search_availability_filter import SearchAvailabilityFilter
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SearchAvailabilityQuery(UncheckedBaseModel):
    """
    The query used to search for buyer-accessible availabilities of bookings.
    """

    filter: SearchAvailabilityFilter = pydantic.Field()
    """
    The query filter to search for buyer-accessible availabilities of existing bookings.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
