# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_account import LoyaltyAccountParams


class CreateLoyaltyAccountResponseParams(typing_extensions.TypedDict):
    """
    A response that includes loyalty account created.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    loyalty_account: typing_extensions.NotRequired[LoyaltyAccountParams]
    """
    The newly created loyalty account.
    """
