# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.gift_card_activity_clear_balance_reason import GiftCardActivityClearBalanceReason


class GiftCardActivityClearBalanceParams(typing_extensions.TypedDict):
    """
    Represents details about a `CLEAR_BALANCE` [gift card activity type](entity:GiftCardActivityType).
    """

    reason: GiftCardActivityClearBalanceReason
    """
    The reason the gift card balance was cleared.
    See [Reason](#type-reason) for possible values
    """
