# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .team_member import TeamMember
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class UpdateTeamMemberRequest(UncheckedBaseModel):
    """
    Represents an update request for a `TeamMember` object.
    """

    team_member: typing.Optional[TeamMember] = pydantic.Field(default=None)
    """
    The team member fields to add, change, or clear. Fields can be cleared using a null value. To update
    `wage_setting.job_assignments`, you must provide the complete list of job assignments. If needed, call
    [ListJobs](api-endpoint:Team-ListJobs) to get the required `job_id` values.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
