# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementUnitLength = typing.Union[
    typing.Literal[
        "IMPERIAL_INCH",
        "IMPERIAL_FOOT",
        "IMPERIAL_YARD",
        "IMPERIAL_MILE",
        "METRIC_MILLIMETER",
        "METRIC_CENTIMETER",
        "METRIC_METER",
        "METRIC_KILOMETER",
    ],
    typing.Any,
]
