# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .vendor import VendorParams


class UpdateVendorRequestParams(typing_extensions.TypedDict):
    """
    Represents an input to a call to [UpdateVendor](api-endpoint:Vendors-UpdateVendor).
    """

    idempotency_key: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A client-supplied, universally unique identifier (UUID) for the
    request.
    
    See [Idempotency](https://developer.squareup.com/docs/build-basics/common-api-patterns/idempotency) in the
    [API Development 101](https://developer.squareup.com/docs/buildbasics) section for more
    information.
    """

    vendor: VendorParams
    """
    The specified [Vendor](entity:Vendor) to be updated.
    """
