# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class TimeRangeParams(typing_extensions.TypedDict):
    """
    Represents a generic time range. The start and end values are
    represented in RFC 3339 format. Time ranges are customized to be
    inclusive or exclusive based on the needs of a particular endpoint.
    Refer to the relevant endpoint-specific documentation to determine
    how time ranges are handled.
    """

    start_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A datetime value in RFC 3339 format indicating when the time range
    starts.
    """

    end_at: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A datetime value in RFC 3339 format indicating when the time range
    ends.
    """
