# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .employee import EmployeeParams
from .error import ErrorParams


class ListEmployeesResponseParams(typing_extensions.TypedDict):
    employees: typing_extensions.NotRequired[typing.Sequence[EmployeeParams]]
    cursor: typing_extensions.NotRequired[str]
    """
    The token to be used to retrieve the next page of results.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
