# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class BulkDeleteLocationCustomAttributesResponseLocationCustomAttributeDeleteResponseParams(
    typing_extensions.TypedDict
):
    """
    Represents an individual delete response in a [BulkDeleteLocationCustomAttributes](api-endpoint:LocationCustomAttributes-BulkDeleteLocationCustomAttributes)
    request.
    """

    location_id: typing_extensions.NotRequired[str]
    """
    The ID of the location associated with the custom attribute.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors that occurred while processing the individual LocationCustomAttributeDeleteRequest request
    """
