# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_reward import LoyaltyRewardParams


class GetLoyaltyRewardResponseParams(typing_extensions.TypedDict):
    """
    A response that includes the loyalty reward.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    reward: typing_extensions.NotRequired[LoyaltyRewardParams]
    """
    The loyalty reward retrieved.
    """
