# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class EventDataParams(typing_extensions.TypedDict):
    type: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the affected object’s type.
    """

    id: typing_extensions.NotRequired[str]
    """
    The ID of the affected object.
    """

    deleted: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    This is true if the affected object has been deleted; otherwise, it's absent.
    """

    object: typing_extensions.NotRequired[typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]]]
    """
    An object containing fields and values relevant to the event. It is absent if the affected object has been deleted.
    """
