# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams
from ..types.gift_card_activity_adjust_decrement_reason import GiftCardActivityAdjustDecrementReason


class GiftCardActivityAdjustDecrementParams(typing_extensions.TypedDict):
    """
    Represents details about an `ADJUST_DECREMENT` [gift card activity type](entity:GiftCardActivityType).
    """

    amount_money: MoneyParams
    """
    The amount deducted from the gift card balance. This value is a positive integer.
    """

    reason: GiftCardActivityAdjustDecrementReason
    """
    The reason the gift card balance was adjusted.
    See [Reason](#type-reason) for possible values
    """
