# This file was auto-generated by Fern from our API Definition.

import typing

LocationCapability = typing.Union[
    typing.Literal["CREDIT_CARD_PROCESSING", "AUTOMATIC_TRANSFERS", "UNLINKED_REFUNDS"], typing.Any
]
