# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class BulkSwapPlanResponseParams(typing_extensions.TypedDict):
    """
    Defines output parameters in a response of the
    [BulkSwapPlan](api-endpoint:Subscriptions-BulkSwapPlan) endpoint.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered during the request.
    """

    affected_subscriptions: typing_extensions.NotRequired[int]
    """
    The number of affected subscriptions.
    """
