# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .vendor import VendorParams


class GetVendorResponseParams(typing_extensions.TypedDict):
    """
    Represents an output from a call to [RetrieveVendor](api-endpoint:Vendors-RetrieveVendor).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Errors encountered when the request fails.
    """

    vendor: typing_extensions.NotRequired[VendorParams]
    """
    The successfully retrieved [Vendor](entity:Vendor) object.
    """
