# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SiteParams(typing_extensions.TypedDict):
    """
    Represents a Square Online site, which is an online store for a Square seller.
    """

    id: typing_extensions.NotRequired[str]
    """
    The Square-assigned ID of the site.
    """

    site_title: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The title of the site.
    """

    domain: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The domain of the site (without the protocol). For example, `mysite1.square.site`.
    """

    is_published: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Indicates whether the site is published.
    """

    created_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the site was created, in RFC 3339 format.
    """

    updated_at: typing_extensions.NotRequired[str]
    """
    The timestamp of when the site was last updated, in RFC 3339 format.
    """
