# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class CatalogQueryItemsForItemOptionsParams(typing_extensions.TypedDict):
    """
    The query filter to return the items containing the specified item option IDs.
    """

    item_option_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    A set of `CatalogItemOption` IDs to be used to find associated
    `CatalogItem`s. All Items that contain all of the given Item Options (in any order)
    will be returned.
    """
