# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .shift_filter import ShiftFilterParams
from .shift_sort import ShiftSortParams


class ShiftQueryParams(typing_extensions.TypedDict):
    """
    The parameters of a `Shift` search query, which includes filter and sort options.

    Deprecated at Square API version 2025-05-21. See the [migration notes](https://developer.squareup.com/docs/labor-api/what-it-does#migration-notes).
    """

    filter: typing_extensions.NotRequired[ShiftFilterParams]
    """
    Query filter options.
    """

    sort: typing_extensions.NotRequired[ShiftSortParams]
    """
    Sort order details.
    """
