# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing


class SubscriptionSourceParams(typing_extensions.TypedDict):
    """
    The origination details of the subscription.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name used to identify the place (physical or digital) that
    a subscription originates. If unset, the name defaults to the name
    of the application that created the subscription.
    """
