# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .transaction import TransactionParams


class ListTransactionsResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields that are included in the response body of
    a request to the [ListTransactions](api-endpoint:Transactions-ListTransactions) endpoint.

    One of `errors` or `transactions` is present in a given response (never both).
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    transactions: typing_extensions.NotRequired[typing.Sequence[TransactionParams]]
    """
    An array of transactions that match your query.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    A pagination cursor for retrieving the next set of results,
    if any remain. Provide this value as the `cursor` parameter in a subsequent
    request to this endpoint.
    
    See [Paginating results](https://developer.squareup.com/docs/working-with-apis/pagination) for more information.
    """
