# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .employee_wage import EmployeeWageParams
from .error import ErrorParams


class ListEmployeeWagesResponseParams(typing_extensions.TypedDict):
    """
    The response to a request for a set of `EmployeeWage` objects. The response contains
    a set of `EmployeeWage` objects.
    """

    employee_wages: typing_extensions.NotRequired[typing.Sequence[EmployeeWageParams]]
    """
    A page of `EmployeeWage` results.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The value supplied in the subsequent request to fetch the next page
    of `EmployeeWage` results.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
