# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .loyalty_reward import LoyaltyRewardParams


class SearchLoyaltyRewardsResponseParams(typing_extensions.TypedDict):
    """
    A response that includes the loyalty rewards satisfying the search criteria.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    rewards: typing_extensions.NotRequired[typing.Sequence[LoyaltyRewardParams]]
    """
    The loyalty rewards that satisfy the search criteria.
    These are returned in descending order by `updated_at`.
    """

    cursor: typing_extensions.NotRequired[str]
    """
    The pagination cursor to be used in a subsequent 
    request. If empty, this is the final response.
    """
