# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .delete_customer_response import DeleteCustomerResponseParams
from .error import ErrorParams


class BulkDeleteCustomersResponseParams(typing_extensions.TypedDict):
    """
    Defines the fields included in the response body from the
    [BulkDeleteCustomers](api-endpoint:Customers-BulkDeleteCustomers) endpoint.
    """

    responses: typing_extensions.NotRequired[typing.Dict[str, DeleteCustomerResponseParams]]
    """
    A map of responses that correspond to individual delete requests, represented by
    key-value pairs.
    
    Each key is the customer ID that was specified for a delete request and each value
    is the corresponding response.
    If the request succeeds, the value is an empty object (`{ }`).
    If the request fails, the value contains any errors that occurred during the request.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any top-level errors that prevented the bulk operation from running.
    """
