# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .order_state import OrderState
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class SearchOrdersStateFilter(UncheckedBaseModel):
    """
    Filter by the current order `state`.
    """

    states: typing.List[OrderState] = pydantic.Field()
    """
    States to filter for.
    See [OrderState](#type-orderstate) for possible values
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
