# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .workweek_config import WorkweekConfigParams
import typing
from .error import ErrorParams


class UpdateWorkweekConfigResponseParams(typing_extensions.TypedDict):
    """
    The response to a request to update a `WorkweekConfig` object. The response contains
    the updated `WorkweekConfig` object and might contain a set of `Error` objects if
    the request resulted in errors.
    """

    workweek_config: typing_extensions.NotRequired[WorkweekConfigParams]
    """
    The response object.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """
