# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .money import MoneyParams


class CheckoutMerchantSettingsPaymentMethodsAfterpayClearpayEligibilityRangeParams(typing_extensions.TypedDict):
    """
    A range of purchase price that qualifies.
    """

    min: MoneyParams
    max: MoneyParams
