# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from .invoice import InvoiceParams
import typing
from .error import ErrorParams


class PublishInvoiceResponseParams(typing_extensions.TypedDict):
    """
    Describes a `PublishInvoice` response.
    """

    invoice: typing_extensions.NotRequired[InvoiceParams]
    """
    The published invoice.
    """

    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Information about errors encountered during the request.
    """
