# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams


class DeletePaymentLinkResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    id: typing_extensions.NotRequired[str]
    """
    The ID of the link that is deleted.
    """

    cancelled_order_id: typing_extensions.NotRequired[str]
    """
    The ID of the order that is canceled. When a payment link is deleted, Square updates the
    the `state` (of the order that the checkout link created) to CANCELED.
    """
