# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.sort_order import SortOrder


class TerminalActionQuerySortParams(typing_extensions.TypedDict):
    sort_order: typing_extensions.NotRequired[SortOrder]
    """
    The order in which results are listed.
    - `ASC` - Oldest to newest.
    - `DESC` - Newest to oldest (default).
    See [SortOrder](#type-sortorder) for possible values
    """
