# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
from ..types.shift_sort_field import ShiftSortField
from ..types.sort_order import SortOrder


class ShiftSortParams(typing_extensions.TypedDict):
    """
    Sets the sort order of search results.

    Deprecated at Square API version 2025-05-21. See the [migration notes](https://developer.squareup.com/docs/labor-api/what-it-does#migration-notes).
    """

    field: typing_extensions.NotRequired[ShiftSortField]
    """
    The field to sort on.
    See [ShiftSortField](#type-shiftsortfield) for possible values
    """

    order: typing_extensions.NotRequired[SortOrder]
    """
    The order in which results are returned. Defaults to DESC.
    See [SortOrder](#type-sortorder) for possible values
    """
