# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions


class CollectedDataParams(typing_extensions.TypedDict):
    input_text: typing_extensions.NotRequired[str]
    """
    The buyer's input text.
    """
