# This file was auto-generated by Fern from our API Definition.

import typing

GiftCardActivityClearBalanceReason = typing.Union[
    typing.Literal["SUSPICIOUS_ACTIVITY", "REUSE_GIFTCARD", "UNKNOWN_REASON"], typing.Any
]
