# This file was auto-generated by Fern from our API Definition.

import typing_extensions
import typing_extensions
import typing
from .error import ErrorParams
from .inventory_count import InventoryCountParams
from .inventory_change import InventoryChangeParams


class BatchChangeInventoryResponseParams(typing_extensions.TypedDict):
    errors: typing_extensions.NotRequired[typing.Sequence[ErrorParams]]
    """
    Any errors that occurred during the request.
    """

    counts: typing_extensions.NotRequired[typing.Sequence[InventoryCountParams]]
    """
    The current counts for all objects referenced in the request.
    """

    changes: typing_extensions.NotRequired[typing.Sequence[InventoryChangeParams]]
    """
    Changes created for the request.
    """
